@@ -30,9 +30,7 @@
 
 #define NODE_FRIENDS_ROOT "friendsList"
 
-#define FILE_INBOX_DATA "/messages_inbox.xml"
-
-#define FILE_OUTBOX_DATA "/messages_outbox.xml"
+#define FILE_MESSAGES_DATA "/messages.xml"
 
 #define NODE_MESSAGES_ROOT "messageList"
 
@@ -48,8 +46,7 @@ class Account: public QObject
 private:
     FriendList friends; // list of loaded friends.
     AlbumList albums; // list of my albums.
-    MessageList inboxMessages; // list of inbox messages.
-    MessageList outboxMessages; // list of outbox messages.
+    MessageList messages; // list of inbox messages.
     MessageList draftMessages; // list of drafts of messages.
     QString settings; // account settings. Uses in driver.
     QString oldSettings; // old account settings. Used if user didn't work with application
@@ -96,13 +93,9 @@ public:
     */
     void setAlbumList(const AlbumList& list);
 
-    MessageList getInboxMessageList();
+    MessageList getMessageList();
 
-    void setInboxMessageList(const MessageList&);
-
-    MessageList getOutboxMessageList();
-
-    void setOutboxMessageList(const MessageList&);
+    void setMessageList(const MessageList&);
 
     void setDraftMessages(const MessageList&);
 
@@ -126,6 +119,9 @@ public:
     // true if first request is success, otherwise false
     bool isNetworkEnabled;
 
+signals:
+    void draftsUpdated(MessageList draftMessages);
+
 private slots:
     void gotSettings(QString accountId, QString settings);
 };
