@@ -149,9 +149,8 @@ QString Friend::name() const
     else
         ret = this->_firstName;
 
-    if (!(this->_firstName.isEmpty() && this->_lastName.isEmpty()))
+    if (ret.length() > 0 && this->_lastName.length() > 0)
         ret += " ";
-
     ret += this->_lastName;
 
     return ret;
@@ -189,71 +188,104 @@ QDomElement Friend::toQDomElement(QDomDocument& doc, const Friend& src, const bo
     node.appendChild(t);
 
     // First Name
-    node = doc.createElement(NODE_FRIEND_FIRST_NAME);
-    t = doc.createTextNode(src._firstName);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!src._firstName.isEmpty())
+    {
+        node = doc.createElement(NODE_FRIEND_FIRST_NAME);
+        t = doc.createTextNode(src._firstName);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     // Nick Name
-    node = doc.createElement(NODE_FRIEND_NICK_NAME);
-    t = doc.createTextNode(src._nickName);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!src._nickName.isEmpty())
+    {
+        node = doc.createElement(NODE_FRIEND_NICK_NAME);
+        t = doc.createTextNode(src._nickName);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     // Last Name
-    node = doc.createElement(NODE_FRIEND_LAST_NAME);
-    t = doc.createTextNode(src._lastName);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!src._lastName.isEmpty())
+    {
+        node = doc.createElement(NODE_FRIEND_LAST_NAME);
+        t = doc.createTextNode(src._lastName);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     // avatar
-    node = doc.createElement(NODE_FRIEND_ICON);
-    t = doc.createTextNode(src._icon);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!src._icon.isEmpty())
+    {
+        node = doc.createElement(NODE_FRIEND_ICON);
+        t = doc.createTextNode(src._icon);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     // avatar url
-    node = doc.createElement(NODE_FRIEND_ICON_URL);
-    t = doc.createTextNode(src._icon_url);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!src._icon_url.isEmpty())
+    {
+        node = doc.createElement(NODE_FRIEND_ICON_URL);
+        t = doc.createTextNode(src._icon_url);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     if (addOptionalInfo) {
         // gender
-        node = doc.createElement(NODE_FRIEND_GENDER);
-        t = doc.createTextNode(src._gender);
-        ret.appendChild(node);
-        node.appendChild(t);
+        if (!src._gender.isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_GENDER);
+            t = doc.createTextNode(src._gender);
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
 
         // birthday
-        node = doc.createElement(NODE_FRIEND_BIRTHDAY);
-        t = doc.createTextNode(src._birthday);
-        ret.appendChild(node);
-        node.appendChild(t);
+        if (!src._birthday.isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_BIRTHDAY);
+            t = doc.createTextNode(src._birthday);
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
 
         // mobile phone
-        node = doc.createElement(NODE_FRIEND_MOBILE_PHONE);
-        t = doc.createTextNode(src._mobilePhone);
-        ret.appendChild(node);
-        node.appendChild(t);
+        if (!src._mobilePhone.isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_MOBILE_PHONE);
+            t = doc.createTextNode(src._mobilePhone);
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
 
         // home phone
-        node = doc.createElement(NODE_FRIEND_HOME_PHONE);
-        t = doc.createTextNode(src._homePhone);
-        ret.appendChild(node);
-        node.appendChild(t);
+        if (!src._homePhone.isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_HOME_PHONE);
+            t = doc.createTextNode(src._homePhone);
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
 
         // city
-        node = doc.createElement(NODE_FRIEND_CITY);
-        t = doc.createTextNode(src._city);
-        ret.appendChild(node);
-        node.appendChild(t);
+        if (!src._city.isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_CITY);
+            t = doc.createTextNode(src._city);
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
 
         // country
-        node = doc.createElement(NODE_FRIEND_COUNTRY);
-        t = doc.createTextNode(src._country);
-        ret.appendChild(node);
-        node.appendChild(t);
+        if (!src._country.isEmpty())
+        {
+            node = doc.createElement(NODE_FRIEND_COUNTRY);
+            t = doc.createTextNode(src._country);
+            ret.appendChild(node);
+            node.appendChild(t);
+        }
     }
 
     return ret;
@@ -356,17 +388,33 @@ void Friend::setAlbumList(const AlbumList& list, const QString& accountId, const
 
 Friend& Friend::operator =(const Friend& src)
 {
-//    Friend *ret = new Friend(src);
-//    qDebug() << "operator=(" << src.name << ", " << ret->name;
-//    return *ret;
     Friend::copyData(this, &src);
 
     return *this;
 }
 
+bool Friend::operator <(const Friend& fr1) const
+{
+    // compare names
+    if (this->online() == fr1.online())
+        return this->name() < fr1.name();
+
+    // if this is online then prefer
+    if (this->online())
+        return true;
+
+    // fr1 is online, prefer
+    return false;
+}
+
+bool Friend::operator ==(const Friend& fr1) const
+{
+    return this->name() == fr1.name();
+}
+
 void Friend::storeData()
 {
-    if (this->accountId.isEmpty() || this->ownerId.isEmpty())
+    if (this->isEmpty())
         return;
 
     // store albums into cache
@@ -404,7 +452,7 @@ Friend Friend::loadData(const QString& serviceId, const QString& accountId, cons
     return Friend::fromQDomElement(doc.firstChildElement(), accountId, serviceId);
 }
 
-bool Friend::isFullProfile() const
+bool Friend::hasFullProfile() const
 {
     QFile file(Utils::getAccountDir(this->accountId) + QString(FILE_OWNER_DATA).arg(this->ownerId));
     if (file.exists())
@@ -487,3 +535,8 @@ FriendList Friend::mergeLists(FriendList src1, FriendList src2)
 
     return ret;
 }
+
+bool Friend::isEmpty() const
+{
+    return this->accountId.isEmpty() || this->ownerId.isEmpty();
+}
