@@ -280,7 +280,7 @@ public:
 
       \return bool true if full profile downloaded, otherwise - false
      */
-    bool isFullProfile() const;
+    bool hasFullProfile() const;
 
     /*!
      \brief Gets list of profiles from meta profile.
@@ -387,6 +387,16 @@ public:
      */
     Friend& operator=(const Friend&);
 
+    /*!
+      \brief compare names of two friends.
+      */
+    bool operator <(const Friend& fr1) const;
+
+    /*!
+      \brief compare names of two friends.
+      */
+    bool operator ==(const Friend& fr1) const;
+
     /*!
      \brief Copies data from one Friend class to another.
 
@@ -413,6 +423,8 @@ public:
       \return new instance of Friend class
      */
     static Friend loadData(const QString& serviceId, const QString& accountId, const QString& ownerId);
+
+    bool isEmpty() const;
 };
 
 #endif // FRIEND_H
