@@ -63,6 +63,9 @@
 #define GET_COUNT_INBOX_BYTIME "getCountInboxByTime"
 #define GET_COUNT_OUTBOX_BYTIME "getCountOutboxByTime"
 
+#define GET_LIST_THREADS "getListThreads"
+#define GET_LIST_THREAD_MESSAGES "getListThreadMessages"
+
 #define GET_NEW_MESSAGES "getNewInboxMessages"
 #define READ_MESSAGE "readMessage"
 #define SEND_MESSAGE "sendMessage"
