@@ -2,21 +2,30 @@
 #include "ui_imagebrowserpanel.h"
 
 #include <QTimer>
+#include <QToolBar>
 
-ImageBrowserPanel::ImageBrowserPanel(QWidget *parent) :
+#include "filter/servicefilter.h"
+#include "filter/filtermanager.h"
+#include "widgets/profilebrowser.h"
+#include "widgets/albuminfowidget.h"
+
+ImageBrowserPanel::ImageBrowserPanel(QFont usedFont, QWidget *parent) :
         QWidget(parent),
         ui(new Ui::ImageBrowserPanel), state(WindowFriendAlbum), isPortraitMode(false)
 {
+    this->usedFont = usedFont;
     this->sm = new ServiceMgr(this);
     ui->setupUi(this);
     init();
 
-    this->isSkipFriendUpdate = false;
     this->isFriendsUpdate = false;
     this->isAlbumsUpdate = false;
     this->isPhotosUpdate = false;
     this->isFeedUpdate = false;
 
+    this->isPhotosWidthSet = false;
+    photosWidth = 0;
+
     //connect to signals from service manager
     connect(sm, SIGNAL(updateFriends(FriendList, bool)),
             this, SLOT(updateListFriends(FriendList, bool)));
@@ -43,20 +52,23 @@ ImageBrowserPanel::ImageBrowserPanel(QWidget *parent) :
     this->peopleradb->toggle();
 }
 
-ImageBrowserPanel::ImageBrowserPanel(ServiceMgr *mgr, QWidget *parent) :
+ImageBrowserPanel::ImageBrowserPanel(QFont usedFont, ServiceMgr *mgr, QWidget *parent) :
     QWidget(parent),
     ui(new Ui::ImageBrowserPanel), state(WindowFriendAlbum), isPortraitMode(false)
 {
+    this->usedFont = usedFont;
     this->sm = mgr;
     ui->setupUi(this);
     init();
 
-    this->isSkipFriendUpdate = false;
     this->isFriendsUpdate = false;
     this->isAlbumsUpdate = false;
     this->isPhotosUpdate = false;
     this->isFeedUpdate = false;
 
+    this->isPhotosWidthSet = false;
+    photosWidth = 0;
+
     //connect to signals from service manager
     connect(sm, SIGNAL(updateFriends(FriendList, bool)),
             this, SLOT(updateListFriends(FriendList, bool)));
@@ -92,17 +104,24 @@ void ImageBrowserPanel::init()
 {
     // radio buttons
     peopleradb = new QRadioButton(tr("People (%1)").arg("0"));
+#ifdef Q_WS_MAEMO_5
+    peopleradb->setText(QString("0"));
+#endif
+
     ui->layoutFriendsTop->addWidget(peopleradb, 1);
     connect(peopleradb, SIGNAL(toggled(bool)), this, SLOT(showFriendPanel(bool)));
     peopleradb->setIcon(QIcon::fromTheme("general_contacts", QIcon(":/res/general_contacts.png")));
 
     newsradb = new QRadioButton(tr("News (%1)").arg("0"));
+#ifdef Q_WS_MAEMO_5
+    newsradb->setText(QString("0"));
+#endif
+
     ui->layoutFriendsTop->addWidget(newsradb, 1);
     newsradb->setIcon(QIcon::fromTheme("general_rss", QIcon(":/res/general_rss.png")));
 
     ui->layoutFriendsTop->setSpacing(0);
 
-
     // friends list
     QIcon icon;
     ui->layoutFriendsTop->addWidget(buttonRefreshFriends = new QPushButton(this), 0);
@@ -110,17 +129,8 @@ void ImageBrowserPanel::init()
     buttonRefreshFriends->setIcon(QIcon::fromTheme("general_refresh",
                                                    QIcon(":/res/general_refresh.png")));
 
-    ui->listFriends->setStyleSheet("text-align: left; image-position: center;");
-    ui->listFriends->setFont(this->usedFont);
-
-    // friends filter
-    ui->layoutFriendsBottom->addWidget(editOwnr = new HintEdit(this));
-    ui->layoutFriendsBottom->addWidget(buttonEditOwnr = new QPushButton(this));
-
-    buttonEditOwnr->setIcon(QIcon::fromTheme("general_backspace",
-                                             QIcon(":/res/general_backspace.png")));
-    buttonEditOwnr->setFlat(TRUE);
-    editOwnr->setHintText(tr("Type a name..."));
+    this->friendsPanel = new QFriendListWidget(this->usedFont, sm, this);
+    this->ui->layoutFriends->addWidget(this->friendsPanel);
 
     // albums
     this->albumsTopPanel = new QTopPanel(this);
@@ -139,6 +149,12 @@ void ImageBrowserPanel::init()
     this->ui->listAlbums->setFont(this->usedFont);
     this->albumsTopPanel->setFont(this->usedFont);
 
+    // Profile info widget (ProfileBrowser) for albums top panel
+    this->profileInfoWidget = new ProfileBrowser(this->sm, false, this->albumsTopPanel);
+    this->profileInfoWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
+    this->albumsTopPanel->setInfoWidget(this->profileInfoWidget);
+    connect(this, SIGNAL(showFriendInfo(Friend)), this->profileInfoWidget, SLOT(setProfile(Friend)));
+
     // photos
     this->photosTopPanel = new QTopPanel(this);
     this->ui->layoutPhotos->insertWidget(0, this->photosTopPanel);
@@ -155,15 +171,23 @@ void ImageBrowserPanel::init()
     this->ui->listPhotos->setFont(this->usedFont);
     this->photosTopPanel->setFont(this->usedFont);
 
+    // Album info widget for photos top panel
+    this->albumInfoWidget = new AlbumInfoWidget(this->photosTopPanel);
+    this->photosTopPanel->setInfoWidget(this->albumInfoWidget);
+    connect(this, SIGNAL(showAlbumInfo(Album)), this->albumInfoWidget, SLOT(setAlbum(Album)));
+
+    // Filters
+    QList<QActionGroup*> actionsList = sm->filterManager()->createActions<Album>();
+    foreach (QActionGroup* actions, actionsList) {
+#ifndef Q_WS_MAEMO_5
+        friendsPanel->filtersToolBar()->addSeparator();
+#endif
+        friendsPanel->filtersToolBar()->addActions(actions->actions());
+    }
+
     // signals
-    connect(editOwnr, SIGNAL(textChanged(QString)),
-            this, SLOT(editOwnr_textChanged(QString)));
-    connect(buttonEditOwnr, SIGNAL(clicked()),
-            this, SLOT(buttonResetOwnr_clicked()));
-    connect(ui->listFriends, SIGNAL(itemClicked(QListWidgetItem*)),
-            this, SLOT(ownrSelected(QListWidgetItem*)));
-    connect(ui->listFriends, SIGNAL(itemActivated(QListWidgetItem*)),
-            this, SLOT(ownrSelected(QListWidgetItem*)));
+    connect(this->friendsPanel, SIGNAL(ownerSelected(Friend)),
+            this, SLOT(ownrSelected(Friend)));
     connect(ui->listNews, SIGNAL(itemClicked(QListWidgetItem*)),
             this, SLOT(feedEventSelected(QListWidgetItem*)));
     connect(ui->listAlbums, SIGNAL(itemClicked(QListWidgetItem*)),
@@ -204,49 +228,6 @@ void ImageBrowserPanel::updateAccounts(QString, AccountList )
     }
 }
 
-void ImageBrowserPanel::buttonResetOwnr_clicked()
-{
-    editOwnr->clear();
-}
-
-void ImageBrowserPanel::editOwnr_textChanged(QString str)
-{
-    int num = ui->listFriends->count();
-    if (str.count() > 0) {
-        for (int i = 0; i < num; i++)
-            if (ui->listFriends->item(i)->text().indexOf(str, 0, Qt::CaseInsensitive) < 0)
-                ui->listFriends->item(i)->setHidden(TRUE);
-            else
-                ui->listFriends->item(i)->setHidden(FALSE);
-    } else {
-        for (int i = 0; i < num; i++)
-            ui->listFriends->item(i)->setHidden(FALSE);
-    }
-    ui->listFriends->scrollTo(ui->listFriends->currentIndex());
-}
-
-
-void ImageBrowserPanel::addMeToFriends()
-{
-    bool isEnabledAccountFound = false;
-    Friend myProfile;
-    AccountList accs = this->sm->getAccounts();
-    for (int i = 0; i < accs.length(); i++) {
-        if (accs.at(i)->isNetworkEnabled) {
-            myProfile = accs.at(i)->getProfile(false);
-            isEnabledAccountFound = true;
-            break;
-        }
-    }
-
-    if (!isEnabledAccountFound && accs.length() > 0)
-        myProfile = accs.at(0)->getProfile(false);
-
-    qDebug() << __FILE__<<":" << __LINE__ << ": profile icon:" << myProfile.icon();
-    QListWidgetItem *item = this->createFriendWidget(myProfile);
-    ui->listFriends->insertItem(0, item);
-}
-
 QListWidgetItem * ImageBrowserPanel::createFriendWidget(Friend fr)
 {
     QListWidgetItem *item = new QListWidgetItem(fr.name());
@@ -272,32 +253,35 @@ QListWidgetItem * ImageBrowserPanel::createFriendWidget(Friend fr)
     return item;
 }
 
-void ImageBrowserPanel::ownrSelected(QListWidgetItem *item, bool isNeedUpdateState)
+void ImageBrowserPanel::ownrSelected(Friend fd, bool isNeedUpdateState)
 {
-    qDebug() << item->text();
-    this->setAlbumHeader();
-    QVariant v = item->data(Qt::UserRole);
-    if (v.canConvert<Friend>()) {
-        Friend fd = v.value<Friend>();
-        qDebug() << "Get albums for " << fd.ownerId;
+    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << ": Get albums for " << fd.ownerId;
 
-        if (ui->listFriends->currentRow() == 0) {
-            this->sm->getAlbums(false, true);
-        } else {
-            this->sm->getAlbums(fd, false, true);
-        }
-        this->setAlbumHeader(fd);
+    if (fd.isEmpty())
+        this->sm->getAlbums(false, true);
+    else
+        this->sm->getAlbums(fd, false, true);
+    this->setAlbumHeader(fd);
 
-        if (isNeedUpdateState)
-            this->setState(WindowAlbumFriend);
-    }
+    if (isNeedUpdateState)
+        this->setState(WindowAlbumFriend);
 }
 
-void ImageBrowserPanel::ownrSelected(QListWidgetItem *item)
+void ImageBrowserPanel::ownrSelected(Friend item)
 {
     this->ownrSelected(item, true);
 }
 
+void ImageBrowserPanel::showFriendAlbums(Friend fd)
+{
+    if (!this->peopleradb->isChecked()) {
+        this->peopleradb->toggle();
+    }
+
+    this->friendsPanel->selectFriend(fd);
+    this->ownrSelected(fd, true);
+}
+
 void ImageBrowserPanel::feedEventSelected(QListWidgetItem *item)
 {
     qDebug() << __FILE__ <<":"<< __LINE__ << ":"<< __FUNCTION__<< "()";
@@ -312,21 +296,34 @@ void ImageBrowserPanel::feedEventSelected(QListWidgetItem *item)
 void ImageBrowserPanel::albmSelected(QListWidgetItem *item)
 {
     qDebug() << __FILE__ <<":"<< __LINE__ << ":"<< __FUNCTION__<< "(): Selected album name: " << item->text();
+    this->setState(WindowPhotoAlbum);
+
+    if (!isPhotosWidthSet) {
+        photosWidth = ui->listPhotos->viewport()->rect().width() - 18;
+        this->isPhotosWidthSet = true;
+    }
+
     QVariant v = item->data(Qt::UserRole);
     if (v.canConvert<Album>()) {
         Album fd = v.value<Album>();
         qDebug() << "Get photos for " << fd.albumId;
-        this->sm->getPhotos(fd, false, true);
+        this->sm->getPhotos(fd, false, true, true);
         this->setPhotoHeader(fd);
     } else {
         this->setPhotoHeader();
     }
-    this->setState(WindowPhotoAlbum);
+
 }
 
 QString ImageBrowserPanel::albumItem(const Album& al)
 {
-    QString str = Utils::decodeString(al.title) + "\n";
+    QString name;
+    if (al.title.isEmpty())
+        name = tr("Untitled album");
+    else
+        name = Utils::decodeString(al.title);
+
+    QString str = name + "\n";
     str += tr("%1 photo(s)", "", al.size).arg(al.size) + ".\n";
     if (al.size != 0 && !al.time_update.isEmpty())
         str += tr(" Updated: ") + al.time_update;
@@ -341,7 +338,13 @@ QPixmap ImageBrowserPanel::albumIcon(const Album& al)
         QIcon icon = QIcon::fromTheme("tasklaunch_photos", QIcon(":/res/tasklaunch_photos.png"));
         pm = icon.pixmap(48, QIcon::Normal, QIcon::On);
     } else {
-        pm = pm.scaledToWidth(80, Qt::SmoothTransformation);
+        if (pm.width() > pm.height())
+            pm = pm.copy((pm.width() - pm.height()) / 2, 0, pm.height(), pm.height());
+
+        if (pm.height() > pm.width())
+            pm = pm.copy(0, (pm.height() - pm.width()) / 2, pm.width(), pm.width());
+
+        pm = pm.scaled(QSize(80, 80), Qt::KeepAspectRatio, Qt::SmoothTransformation);
     }
     return pm;
 }
@@ -352,34 +355,49 @@ void ImageBrowserPanel::setAlbumHeader()
     this->albumsTopPanel->setPixmap(QIcon::fromTheme("tasklaunch_photos", QIcon(":/res/tasklaunch_photos.png")).pixmap(48, QIcon::Normal, QIcon::On));
 }
 
-void ImageBrowserPanel::setAlbumHeader(Friend fd)
+void ImageBrowserPanel::setAlbumHeader(const Friend& curFr)
 {
+    Friend fd = curFr;
+    if (fd.isEmpty())
+    {
+        fd = sm->getMyProfile(false);
+    }
     this->albumsTopPanel->setText(Utils::decodeString(fd.name()));
-    QIcon friendIcon = QIcon(fd.icon());
-    if (!friendIcon.isNull())
-        this->albumsTopPanel->setPixmap(friendIcon.pixmap(48, QIcon::Normal, QIcon::On));
-    else
+    QPixmap pm(fd.icon());
+    if (!pm.isNull()) {
+        if (pm.width() > pm.height())
+            pm = pm.copy((pm.width() - pm.height()) / 2, 0, pm.height(), pm.height());
+
+        if (pm.height() > pm.width())
+            pm = pm.copy(0, (pm.height() - pm.width()) / 2, pm.width(), pm.width());
+
+        pm = pm.scaled(QSize(48, 48), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        this->albumsTopPanel->setPixmap(pm);
+    } else {
         this->albumsTopPanel->setPixmap(QIcon::fromTheme("tasklaunch_photos", QIcon(":/res/tasklaunch_photos.png")).pixmap(48, QIcon::Normal, QIcon::On));
+    }
 }
 
 QPixmap ImageBrowserPanel::photoIcon(const Photo& al)
 {
+    int cols = (int)(this->photosWidth / 100);
+    int left = this->photosWidth - cols * 100;
+    int photoSize = (int)((this->photosWidth + left) / cols);
+
     QPixmap pm(al.icon);
     if (pm.isNull()) {
         QIcon icon = QIcon::fromTheme("general_image", QIcon(":/res/general_image.png"));
         pm = icon.pixmap(48, QIcon::Normal, QIcon::On);
     } else {
-        if (pm.width() > pm.height()) {
-            pm = pm.scaledToWidth(110, Qt::SmoothTransformation);
-        } else {
-            if (pm.height() > pm.width())
-                pm = pm.scaledToHeight(110, Qt::SmoothTransformation);
-            else
-                pm = pm.scaled(QSize(110, 110), Qt::KeepAspectRatio, Qt::SmoothTransformation);
-        }
+        if (pm.width() > pm.height())
+            pm = pm.copy((pm.width() - pm.height()) / 2, 0, pm.height(), pm.height());
+
+        if (pm.height() > pm.width())
+            pm = pm.copy(0, (pm.height() - pm.width()) / 2, pm.width(), pm.width());
+
+        pm = pm.scaled(QSize(photoSize - 12, photoSize - 12), Qt::KeepAspectRatio, Qt::SmoothTransformation);
     }
 
-    // 130,130
     return pm;
 }
 
@@ -398,14 +416,12 @@ QPixmap ImageBrowserPanel::photoIcon(const QAttachment& at)
 void ImageBrowserPanel::setPhotoHeader()
 {
     QIcon icon = QIcon::fromTheme("general_image", QIcon(":/res/general_image.png"));
-    this->photosTopPanel->setPixmap(icon.pixmap(64, QIcon::Normal, QIcon::On));
+    this->photosTopPanel->setPixmap(icon.pixmap(48, QIcon::Normal, QIcon::On));
     this->photosTopPanel->setText(tr("Photo(s):"));
 }
 
 void ImageBrowserPanel::setPhotoHeader(Album al)
 {
-    bool useDefaultIcon = false;
-
     al.title = cutHeader(al.title);
     al.description = cutHeader(al.description);
 
@@ -413,23 +429,24 @@ void ImageBrowserPanel::setPhotoHeader(Album al)
                          (al.description.isNull() ? "": "\n" +
                           Utils::decodeString(al.description)) +
                          "\n" + tr("%1 photo(s):", "", al.size).arg(al.size));
-    QPixmap *pm = new QPixmap(al.icon);
-    if (pm->isNull()) {
-        useDefaultIcon = true;
+
+    QPixmap pm(al.icon);
+    if (pm.isNull()) {
+        this->photosTopPanel->setPixmap( QIcon::fromTheme("general_image", QIcon(":/res/general_image.png")).pixmap(48, QIcon::Normal, QIcon::On));
     } else {
-        *pm = pm->scaledToWidth(80, Qt::SmoothTransformation);
-        QIcon albumIcon = QIcon(*pm);
-        if (!albumIcon.isNull()) {
-            this->photosTopPanel->setPixmap(albumIcon.pixmap(64, QIcon::Normal, QIcon::On));
-        } else {
-            useDefaultIcon = true;
-        }
+        if (pm.width() > pm.height())
+            pm = pm.copy((pm.width() - pm.height()) / 2, 0, pm.height(), pm.height());
+
+        if (pm.height() > pm.width())
+            pm = pm.copy(0, (pm.height() - pm.width()) / 2, pm.width(), pm.width());
+
+        pm = pm.scaled(QSize(48, 48), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+
+        this->photosTopPanel->setPixmap(pm);
     }
 
-    if (useDefaultIcon) {
-        QIcon icon = QIcon::fromTheme("general_image", QIcon(":/res/general_image.png"));
-        this->photosTopPanel->setPixmap(icon.pixmap(64, QIcon::Normal, QIcon::On));
-    }
+    // Update album info
+    emit showAlbumInfo(al);
 }
 
 void ImageBrowserPanel::photoSelected(QListWidgetItem *item)
@@ -443,11 +460,7 @@ void ImageBrowserPanel::photoSelected(QListWidgetItem *item)
 
 void ImageBrowserPanel::updateListFriends(FriendList list, bool isLastUpdate)
 {
-    // skip non-last friends updates if it possible
-    if (!isLastUpdate && this->isSkipFriendUpdate)
-        return;
-
-    qDebug() << "Start update Friend list process. isLastUpdate=" << isLastUpdate;
+    qDebug() << __FILE__ <<":"<<__LINE__<<":"<<__FUNCTION__<<"(): list.length()="<<list.length() << "; isLastUpdate=" << isLastUpdate;
 
     if (isLastUpdate) {
         this->isFriendsUpdate = false;
@@ -456,133 +469,15 @@ void ImageBrowserPanel::updateListFriends(FriendList list, bool isLastUpdate)
         this->isFriendsUpdate = true;
         buttonRefreshFriends->setIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
     }
+#ifndef Q_WS_MAEMO_5
+    this->peopleradb->setText(tr("People (%1)").arg(list.length()));
+#else
+    this->peopleradb->setText(QString("(%1)").arg(list.length()));
+#endif
 
-    if (list.isEmpty()) {
-        this->ui->listFriends->clear();
-        this->addMeToFriends();
-        if (isLastUpdate) {
-            new QListWidgetItem(tr("No Friends"), this->ui->listFriends);
-        } else {
-            new QListWidgetItem(tr("Download friend list"), this->ui->listFriends);
-        }
-        return;
-    }
+    Friend curFr = this->friendsPanel->getSelectedFriend();
 
-    if (this->ui->listFriends->count() == 0)
-        this->addMeToFriends();
-
-    FriendList newFriends(list);
-    QList<QListWidgetItem *> dels;
-
-    // check that all current friends is contains in new list
-    for (int i = 1; i < ui->listFriends->count(); i++) {
-        bool isFound = false;
-
-        QListWidgetItem *item = ui->listFriends->item(i);
-
-        QVariant v = item->data(Qt::UserRole);
-        if (v.canConvert<Friend>()) {
-            Friend oldFd = v.value<Friend>();
-
-            int removedVal = -1;
-
-            for (int j = 0; j < newFriends.length(); j++) {
-                Friend curFd = newFriends.at(j);
-                if (oldFd.ownerId == curFd.ownerId &&
-                    oldFd.accountId == curFd.accountId) {
-                    removedVal = j;
-                    QImage *img = new QImage(curFd.icon());
-
-                    if (img->height() > img->width())
-                        *img = img->copy(0, (img->height() - img->width()) / 2, img->width(), img->width());
-                    item->setIcon(QIcon(QPixmap::fromImage(*img)));
-
-                    if (item->icon().isNull())
-                        item->setIcon(QIcon::fromTheme("general_default_avatar", QIcon(":/res/general_default_avatar.png")));
-                    v.setValue(curFd);
-                    item->setData(Qt::UserRole, v);
-
-                    if (curFd.online())
-                    {
-                        item->setText(curFd.name() + "\n" + tr("Online"));
-                    }else{
-                        item->setText(curFd.name());
-                    }
-
-                    isFound = true;
-                    delete img;
-                    break;
-                }
-            }
-
-            if (isFound && removedVal >= 0) {
-                newFriends.removeAt(removedVal);
-            } else {
-                qDebug() << "prepare to remove friend with id " << oldFd.ownerId << " from " << oldFd.accountId;
-            }
-        }
-
-        if (!isFound)
-            dels.append(item);
-    }
-
-    qDebug() << "Will be add " << newFriends.length() << " friends and removed " << dels.length() << " records. Total widgets: " << ui->listFriends->count();
-
-    // del old friends
-    for (int i = 0; i < dels.length(); i++) {
-        if (dels.at(i)->isSelected()) {
-            this->ui->listFriends->item(0)->setSelected(true);
-            this->ui->listFriends->setCurrentRow(0);
-            //this->ownrSelected(this->ui->listFriends->item(0), false);
-        }
-        delete dels.at(i);
-    }
-
-    // add new Friends with asceding sorting
-    for (int i = 0; i < newFriends.length(); i++) {
-        QListWidgetItem *item = createFriendWidget(newFriends.at(i));
-        if (this->ui->listFriends->count() <= 1)
-            this->ui->listFriends->addItem(item);
-
-        bool flag = false;
-        for (int j = 1; j < this->ui->listFriends->count(); j++) {
-            if (this->ui->listFriends->item(j)->text().compare(item->text()) > 0) {
-                this->ui->listFriends->insertItem(j, item);
-                flag = true;
-                break;
-            }
-        }
-        if (!flag)
-            this->ui->listFriends->addItem(item);
-    }
-
-    if (this->ui->listFriends->selectedItems().count() == 0) {
-        qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): no selected items in friend list!";
-        this->ui->listFriends->setCurrentRow(0);
-        //this->ui->listFriends->item(0)->setSelected(true);
-        //this->ui->listFriends->selectedItems().append(this->ui->listFriends->item(0));
-        //this->ownrSelected(this->ui->listFriends->item(0), false);
-        qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): Selected me!!!";
-    }
-
-    // update album header for friend
-    if (this->ui->listFriends->selectedItems().length() > 0) {
-        QVariant v = this->ui->listFriends->selectedItems().at(0)->data(Qt::UserRole);
-        Friend fd = v.value<Friend>();
-        this->setAlbumHeader(fd);
-    }
-    this->peopleradb->setText(tr("People (%1)").arg(this->ui->listFriends->count()));
-
-    // set timeout for next updates
-    if (!isLastUpdate) {
-        this->isSkipFriendUpdate = true;
-        QTimer::singleShot(1000, this, SLOT(disableFriendSkipUpdate()));
-    }
-}
-
-void ImageBrowserPanel::disableFriendSkipUpdate()
-{
-    this->isSkipFriendUpdate = false;
+    this->setAlbumHeader(curFr);
 }
 
 void ImageBrowserPanel::updateListAlbums(Friend owner, AlbumList list, bool isLastUpdate)
@@ -590,25 +485,19 @@ void ImageBrowserPanel::updateListAlbums(Friend owner, AlbumList list, bool isLa
     qDebug() << __FILE__ <<":"<<__LINE__<<":"<<__FUNCTION__<<"(): owner=" << owner.ownerId << ";list.length()="<<list.length() << "; isLastUpdate=" << isLastUpdate;
     bool isFoundSelectedFriend = false;
 
-    if (this->ui->listFriends->selectedItems().length() > 0 &&
-        !this->ui->listFriends->item(0)->isSelected()) {
-        // check correctness that list was return for selected friend
-        QList<QListWidgetItem *> selFriends = ui->listFriends->selectedItems();
-        for (int i = 0; i < selFriends.length(); i++) {
-            QVariant v = selFriends[i]->data(Qt::UserRole);
-            if (v.canConvert<Friend>()) {
-                Friend fd = v.value<Friend>();
-                if (fd.hasProfile(owner)) {
-                    isFoundSelectedFriend = true;
-                    break;
-                }
-            }
-        }
-    } else {
-        // it is my albums
-        AccountList accs = this->sm->getAccounts();
+    AccountList accs = this->sm->getAccounts();
+    Friend fd = this->friendsPanel->getSelectedFriend();
+
+    if (fd.hasProfile(owner)) {
+        isFoundSelectedFriend = true;
+    }
+
+    // check my albums
+    if (!isFoundSelectedFriend && fd.isEmpty())
+    {
         for (int i = 0; i < accs.length(); i++) {
-            if (accs.at(i)->getProfile(false).ownerId == owner.ownerId) {
+            if (accs.at(i)->getProfile(false).hasProfile(owner))
+            {
                 isFoundSelectedFriend = true;
                 break;
             }
@@ -849,7 +738,6 @@ void ImageBrowserPanel::refreshFriends(bool isNeedUpdate)
     {
         // friends refresh
         if (!this->isFriendsUpdate) {
-            buttonResetOwnr_clicked();
             this->isFriendsUpdate = true;
             buttonRefreshFriends->setIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
             sm->getFriends(isNeedUpdate, true);
@@ -878,18 +766,10 @@ void ImageBrowserPanel::refreshAlbums(bool isNeedUpdate)
     qDebug() << __FILE__ <<":"<<__LINE__<<":"<<__FUNCTION__<<"(): isNeedUpdate=" << isNeedUpdate << "; albumUpdate=" << this->isAlbumsUpdate;
 
     if (!this->isAlbumsUpdate) {
-        if (this->ui->listFriends->selectedItems().length() > 0
-            && !this->ui->listFriends->item(0)->isSelected()) {
-            QListWidgetItem *item = this->ui->listFriends->selectedItems().at(0);
-            if (item != NULL) {
-                qDebug() << "Update albums for " << item->text();
-                QVariant v = item->data(Qt::UserRole);
-                if (v.canConvert<Friend>()) {
-                    Friend fd = v.value<Friend>();
-                    qDebug() << "Get albums for " << fd.ownerId;
-                    this->sm->getAlbums(fd, isNeedUpdate, true);
-                }
-            }
+        Friend fd = this->friendsPanel->getSelectedFriend();
+        if (!fd.isEmpty()) {
+            qDebug() << "Get albums for " << fd.ownerId;
+            this->sm->getAlbums(fd, isNeedUpdate, true);
         } else {
             qDebug("Try to load my albums");
             this->sm->getAlbums(isNeedUpdate, true);
@@ -921,7 +801,7 @@ void ImageBrowserPanel::refreshPhotos(bool isNeedUpdate)
         if (v.canConvert<Album>()) {
             Album fd = v.value<Album>();
             qDebug() << "Get photos for " << fd.albumId;
-            this->sm->getPhotos(fd, isNeedUpdate, true);
+            this->sm->getPhotos(fd, isNeedUpdate, true, true);
         }
     }
 }
@@ -1001,8 +881,10 @@ void ImageBrowserPanel::setState(WindowState state) {
         this->setImagesVisible(false);
 
         if (isMultiWindow) {
+            this->albumsTopPanel->setBackVisible(false);
             this->setFriendsVisible(true);
         } else {
+            this->albumsTopPanel->setBackVisible(true);
             this->setFriendsVisible(false);
         }
         qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): show albums from friends";
@@ -1012,8 +894,12 @@ void ImageBrowserPanel::setState(WindowState state) {
         this->setImagesVisible(false);
 
         if (isMultiWindow) {
+            this->albumsTopPanel->setBackVisible(false);
+            this->photosTopPanel->setBackVisible(false);
             this->setFriendsVisible(true);
         } else {
+            this->albumsTopPanel->setBackVisible(true);
+            this->photosTopPanel->setBackVisible(true);
             this->setFriendsVisible(false);
         }
         qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): show albums from photos";
@@ -1023,6 +909,7 @@ void ImageBrowserPanel::setState(WindowState state) {
         this->setImagesVisible(false);
 
         if (isMultiWindow) {
+            this->albumsTopPanel->setBackVisible(false);
             this->setAlbumsVisible(true);
         } else {
             this->setAlbumsVisible(false);
@@ -1034,8 +921,11 @@ void ImageBrowserPanel::setState(WindowState state) {
         this->setImagesVisible(true);
 
         if (isMultiWindow) {
+            this->albumsTopPanel->setBackVisible(true);
+            this->photosTopPanel->setBackVisible(false);
             this->setAlbumsVisible(true);
         } else {
+            this->photosTopPanel->setBackVisible(true);
             this->setAlbumsVisible(false);
         }
         qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): show photos";
@@ -1056,35 +946,13 @@ void ImageBrowserPanel::orientationChanged()
     this->setState();
 }
 
-void ImageBrowserPanel::showFriendAlbums(Friend fd)
-{
-    for (int i = 0; i < ui->listFriends->count(); i++) {
-        QListWidgetItem *item = ui->listFriends->item(i);
-
-        QVariant v = item->data(Qt::UserRole);
-        if (v.canConvert<Friend>()) {
-            Friend oldFd = v.value<Friend>();
-
-            if (oldFd.ownerId == fd.ownerId) {
-                ui->listFriends->setCurrentRow(i);
-                ownrSelected(item);
-                break;
-            }
-        }
-    }
-}
-
 void ImageBrowserPanel::showFriendInfo()
 {
-    QListWidgetItem *item = ui->listFriends->item(ui->listFriends->currentRow());
-    if (item != NULL) {
-        QVariant v = item->data(Qt::UserRole);
-        if (v.canConvert<Friend>()) {
-            Friend fd = v.value<Friend>();
-            qDebug() << __FILE__ << "emit showFriendInfo";
-            emit showFriendInfo(fd);
-        }
-    }
+    Friend fd = this->friendsPanel->getSelectedFriend();
+    if (fd.isEmpty())
+        fd = sm->getMyProfile(false);
+    qDebug() << __FILE__ << ":" << __LINE__ << ": emit showFriendInfo for " << fd.accountId;
+    emit showFriendInfo(fd);
 }
 
 QString ImageBrowserPanel::cutHeader(QString text)
@@ -1128,7 +996,13 @@ void ImageBrowserPanel::updateFeed(QEventFeedList list, QEventFeed::FeedType typ
        v.setValue(list.at(i));
        item->setData(Qt::UserRole, v);
    }
-   this->newsradb->setText(tr("News (%1)").arg(this->ui->listNews->count()));
+
+#ifndef Q_WS_MAEMO_5
+    this->newsradb->setText(tr("News (%1)").arg(this->ui->listNews->count()));
+#else
+    this->newsradb->setText(QString("(%1)").arg(this->ui->listNews->count()));
+#endif
+
    this->ui->listNews->repaint();
 }
 
@@ -1137,18 +1011,23 @@ void ImageBrowserPanel::showFriendPanel(bool isShow)
     qDebug() << __FUNCTION__ << "(): isShow=" << isShow;
     if (isShow)
     {
-        this->ui->listFriends->show();
-        this->showAll(this->ui->layoutFriendsBottom);
+        this->friendsPanel->show();
         this->ui->listNews->hide();
+        bool isMultiWindow = this->sm->settings->value(SETTINGS_MULTIPANEL).toBool() && !this->isPortraitMode;
+        setAlbumsVisible(isMultiWindow);
         if (this->isFriendsUpdate)
             buttonRefreshFriends->setIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
         else
             buttonRefreshFriends->setIcon(QIcon::fromTheme("general_refresh",
                                                            QIcon(":/res/general_refresh.png")));
     } else {
-        this->ui->listFriends->hide();
-        this->hideAll(this->ui->layoutFriendsBottom);
+        this->friendsPanel->hide();
+        setAlbumsVisible(false);
         this->ui->listNews->show();
+
+        if (ui->listNews->count() == 0)
+            this->refreshFeed(true);
+
         if (this->isFeedUpdate)
             buttonRefreshFriends->setIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
         else
@@ -1196,5 +1075,32 @@ void ImageBrowserPanel::gotError(QString, QTransport::Action action, bool)
                 buttonRefreshFriends->setIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
         }
         break;
+    case QTransport::getListAlbumsAction:
+        if (this->sm->getNumThreadsAlbumUpdate() == 0)
+        {
+            this->isAlbumsUpdate = false;
+            this->albumsTopPanel->setRefreshIcon(QIcon::fromTheme("general_refresh", QIcon(":/res/general_refresh.png")));
+            if (ui->listAlbums->count() == 0 || ui->listAlbums->item(0)->text().compare(tr("Download albums")) == 0) {
+                ui->listAlbums->clear();
+                new QListWidgetItem(tr("No albums"), ui->listAlbums); //QListWidgetItem *item2 = new
+                ui->listAlbums->setDisabled(true);
+            }
+        } else {
+            this->isAlbumsUpdate = true;
+            this->albumsTopPanel->setRefreshIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
+        }
+        break;
+    case QTransport::getListPhotosAction:
+        if (this->sm->getNumThreadsPhotoUpdate() == 0)
+        {
+            this->isPhotosUpdate = false;
+            this->photosTopPanel->setRefreshIcon(QIcon::fromTheme("general_refresh", QIcon(":/res/general_refresh.png")));
+        } else {
+            this->isPhotosUpdate = true;
+            this->photosTopPanel->setRefreshIcon(QIcon::fromTheme("general_stop", QIcon(":/res/general_stop.png")));
+        }
+        break;
+    default:
+        break;
     }
 }
