@@ -1,13 +1,34 @@
 #include "servicemgr.h"
-#include "qtransport.h"
+
+#include <cassert>
 
 #include <QApplication>
 #include <QTimer>
 
+#include "qtransport.h"
+
+#include "filter/servicefilter.h"
+#include "filter/filtermanager.h"
+
+#include "filter/filterfriendonline.h"
+#include "filter/filterfriendgender.h"
+#include "filter/filtermessagereaded.h"
+#include "filter/filtermessagetype.h"
+
+/*
+ * Datatype functions:
+ *
+ * Friend: getFriends; gotFriends // done
+ * Albums: 3 * getAlbums; gotAlbumList // done
+ * Photos: 2 * getPhotos; gotPhotoList // done
+ * Inbox Messages: getInboxMessages; gotInboxMessageList // done
+ * Outbox Messages: getOutboxMessages; gotOutboxMessageList // done
+ * Comments: getComments; gotComments // done
+ */
+
 ServiceMgr::ServiceMgr(QObject *parent) :
     QObject(parent), friendsUpdate(0), albumsUpdate(0), photosUpdate(0),
-    feedsUpdate(0), inboxMessagesUpdate(0), outboxMessagesUpdate(0),
-    filteredDriver(0)
+    feedsUpdate(0), messagesUpdate(0), filteredDriver(0)
 {
     this->isSkipFriendListUpdate = false;
 
@@ -41,16 +62,15 @@ ServiceMgr::ServiceMgr(QObject *parent) :
 
     connect(this, SIGNAL(updateAccounts(QString,AccountList)), this, SLOT(storeAccounts(QString,AccountList)));
 
+    createFilter();
 }
 
 void ServiceMgr::connectToTransport(Account *account)
 {
     connect(account->transport, SIGNAL(friendsReceived(QString, FriendList, bool)),
             SLOT(gotFriends(QString, FriendList, bool)));
-    connect(account->transport, SIGNAL(inboxMessagesReceived(QString,MessageList, bool)),
-            SLOT(gotInboxMessageList(QString,MessageList,bool)));
-    connect(account->transport, SIGNAL(outboxMessagesReceived(QString,MessageList,bool)),
-            SLOT(gotOutboxMessageList(QString,MessageList,bool)));
+    connect(account->transport, SIGNAL(messagesReceived(QString,MessageList, bool)),
+            SLOT(gotMessageList(QString,MessageList,bool)));
     connect(account->transport, SIGNAL(albumsReceived(QString, QString, AlbumList, bool)),
             SLOT(gotAlbumList(QString, QString, AlbumList, bool)));
     connect(account->transport, SIGNAL(photosReceived(QString, QString, QString, PhotoList, bool)),
@@ -95,7 +115,7 @@ void ServiceMgr::storeAccounts(QString accountId, AccountList)
         if (curAcc->accountId().compare(accountId) == 0)
         {
             curAcc->saveAccount();
-            this->getFeed(curAcc, QEventFeed::photoFeed, true, true);
+//            this->getFeed(curAcc, QEventFeed::photoFeed, true, true);
         }
         QDomElement anode = out.createElement(NODE_ACCOUNT);
         QDomText t = out.createTextNode(curAcc->accountId());
@@ -209,36 +229,54 @@ void ServiceMgr::updateDriverSettings()
 
 FriendList ServiceMgr::getFriends(const bool isNeedUpdate, const bool useSignal)
 {
-    FriendList ret;
-
-    this->cleanThreads();
-
-    for (int i = 0; i < this->accounts.length(); i++) {
-        Account* acc = accounts.at(i);
-        if (!isServiceFiltered(acc)) {
-            FriendList curList = acc->getFriendList();
-            qDebug() << "before merging" << ret.length() << curList.length();
-            ret = Friend::mergeLists(ret, curList);
-            qDebug() << "after merging" << ret.length();
-
-            if (isNeedUpdate || curList.isEmpty()) {
-                QString threadId = QString("getFriends") + this->accounts[i]->transport->accountId;
-
-                // check that thread shouldn't already running
-                if (!this->threads.contains(threadId) && this->accounts.at(i)->isNetworkEnabled) {
-                    // add thread to list
-                    QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getFriends);
-                    this->threads.insert(threadId, status);
-                    this->friendsUpdate++;
-                }
+    // checks that all friend lists was downloaded
+    if (!isNeedUpdate && this->cachedFriendList.length() > 0)
+    {
+        for (int i = 0; i < this->accounts.length(); i++)
+        {
+            if (this->accounts.at(i)->getFriendList().length() == 0)
+            {
+                this->cachedFriendList.clear();
+                break;
             }
         }
     }
 
-    if (useSignal)
-        emit this->updateFriends(ret, this->friendsUpdate > 0 ? false: true);
+    if (isNeedUpdate || this->cachedFriendList.length() == 0)
+    {
+        this->cachedFriendList.clear();
+        this->cleanThreads();
 
-    return ret;
+        for (int i = 0; i < this->accounts.length(); i++) {
+            Account* acc = accounts.at(i);
+            if (!isServiceFiltered(acc)) {
+                FriendList curList = acc->getFriendList();
+                qDebug() << "before merging" << this->cachedFriendList.length() << curList.length();
+                this->cachedFriendList = Friend::mergeLists(this->cachedFriendList, curList);
+                qDebug() << "after merging" << this->cachedFriendList.length();
+
+                if (isNeedUpdate || curList.isEmpty()) {
+                    QString threadId = QString("getFriends") + this->accounts[i]->transport->accountId;
+
+                    // check that thread shouldn't already running
+                    if (!this->threads.contains(threadId) && this->accounts.at(i)->isNetworkEnabled) {
+                        // add thread to list
+                        QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getFriends, true);
+                        this->threads.insert(threadId, status);
+                        this->friendsUpdate++;
+                    }
+                }
+            }
+        }
+        qSort(this->cachedFriendList.begin(), this->cachedFriendList.end());
+    }
+
+    filterManager_->filterList(cachedFriendList);
+
+    if (useSignal)
+        emit this->updateFriends(this->cachedFriendList, this->friendsUpdate > 0 ? false: true);
+
+    return this->cachedFriendList;
 }
 
 void ServiceMgr::gotFriends(QString accountid, FriendList list, bool isLastUpdate)
@@ -248,19 +286,20 @@ void ServiceMgr::gotFriends(QString accountid, FriendList list, bool isLastUpdat
     if (!isLastUpdate && this->isSkipFriendListUpdate)
         return;
 
+    this->cachedFriendList.clear();
+
     // create list of merged lists of friends
-    FriendList ret;
     for (int i = 0; i < this->accounts.length(); i++) {
         Account* acc = accounts.at(i);
         if (!isServiceFiltered(acc)) {
             if (this->accounts[i]->transport->accountId == accountid) {
                 this->accounts[i]->setFriendList(list);
-                ret = Friend::mergeLists(ret, list);
-                qDebug() << "Add to friends " << list.length() << ". Total:" << ret.length();
+                this->cachedFriendList = Friend::mergeLists(this->cachedFriendList, list);
+                qDebug() << "Add to friends " << list.length() << ". Total:" << this->cachedFriendList.length();
             } else {
                 FriendList lst = this->accounts[i]->getFriendList();
-                ret = Friend::mergeLists(ret, lst);
-                qDebug() << "Add to friends " << lst.length() << ". Total:" << ret.length();
+                this->cachedFriendList = Friend::mergeLists(this->cachedFriendList, lst);
+                qDebug() << "Add to friends " << lst.length() << ". Total:" << this->cachedFriendList.length();
             }
         }
     }
@@ -269,7 +308,10 @@ void ServiceMgr::gotFriends(QString accountid, FriendList list, bool isLastUpdat
         this->friendsUpdate--;
     qDebug() << "islastUpdate=" << isLastUpdate << ", friendsUpdate=" << friendsUpdate;
 
-    emit updateFriends(ret, (this->friendsUpdate > 0 ? false: true));
+    filterManager_->filterList(cachedFriendList);
+    qSort(this->cachedFriendList.begin(), this->cachedFriendList.end());
+
+    emit updateFriends(this->cachedFriendList, (this->friendsUpdate > 0 ? false: true));
 
     if (!isLastUpdate)
     {
@@ -287,8 +329,16 @@ AlbumList ServiceMgr::getAlbums(bool isNeedUpdate, bool useSignal)
 {
     AlbumList ret;
 
-    if (this->accounts.length() > 0)
-        return this->getAlbums(this->accounts.at(0)->getProfile(false), isNeedUpdate, useSignal);
+    for (int i = 0; i < this->accounts.length(); i++) {
+        ret.append(this->getAlbums(this->accounts.at(i)->getProfile(false), isNeedUpdate, false));
+    }
+
+    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): this->albumsUpdate=" << this->albumsUpdate;
+
+    filterManager_->filterList(ret);
+
+    if (useSignal && this->accounts.length() > 0)
+        emit this->updateAlbumList(this->accounts.at(0)->getProfile(false), ret, this->albumsUpdate > 0 ? false: true);
 
     return ret;
 }
@@ -301,21 +351,7 @@ AlbumList ServiceMgr::getAlbums(const Friend& curFriend, bool isNeedUpdate, cons
             << " from " << curFriend.accountId << " needUpdate=" << isNeedUpdate << "; this->albumsUpdate="
             << this->albumsUpdate;
 
-    // check for owner album
-    for (int i = 0; i < this->accounts.length(); i++) {
-        if (this->accounts.at(i)->accountId().compare(curFriend.accountId) == 0 &&
-            this->accounts.at(i)->getProfile(false).ownerId.compare(curFriend.ownerId) == 0)
-        {
-            for (int j = 0; j < this->accounts.length(); j++) {
-                if (this->accounts.at(j)->getAlbumList().isEmpty())
-                    isNeedUpdate = true;
-                ret.append(this->accounts.at(j)->getAlbumList());
-            }
-        }
-    }
-
-    if (ret.length() == 0)
-        ret = curFriend.getAlbumList();
+    ret = curFriend.getAlbumList();
 
     this->cleanThreads();
 
@@ -328,7 +364,7 @@ AlbumList ServiceMgr::getAlbums(const Friend& curFriend, bool isNeedUpdate, cons
                 if (this->threads.contains(QString("albums") + curFriend.ownerId))
                     break;
 
-                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getAlbums, curFriend.ownerId);
+                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getAlbums, curFriend.ownerId, true);
                 this->threads.insert(QString("albums") + curFriend.ownerId, status);
                 this->albumsUpdate++;
                 break;
@@ -337,6 +373,9 @@ AlbumList ServiceMgr::getAlbums(const Friend& curFriend, bool isNeedUpdate, cons
     }
 
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): this->albumsUpdate=" << this->albumsUpdate;
+
+    filterManager_->filterList(ret);
+
     if (useSignal)
         emit this->updateAlbumList(curFriend, ret, this->albumsUpdate > 0 ? false: true);
 
@@ -384,10 +423,11 @@ void ServiceMgr::gotAlbumList(QString accountId, QString owner, AlbumList list,
     }
     qDebug() << "islastUpdate=" << isLastUpdate << ", albumsUpdate=" << albumsUpdate << ", accountId=" << accountId << "owner=" << owner;
 
+    filterManager_->filterList(ret);
     emit updateAlbumList(this->getProfile(accountId, owner, false, false, false), ret, this->albumsUpdate > 0 ? false: true);
 }
 
-PhotoList ServiceMgr::getPhotos(const Album& album, const bool isNeedUpdate, const bool useSignal)
+PhotoList ServiceMgr::getPhotos(const Album& album, const bool isNeedUpdate, const bool useSignal, const bool loadIcons)
 {
     bool nUpdate = isNeedUpdate;
     PhotoList ret;
@@ -419,7 +459,7 @@ PhotoList ServiceMgr::getPhotos(const Album& album, const bool isNeedUpdate, con
                 qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "Download photo list for " << album.albumId;
                 if (!this->threads.contains(Photo::getKey(album)))
                 {
-                    QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getPhotos, album.ownerId, album.albumId);
+                    QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getPhotos, album.ownerId, album.albumId, loadIcons);
                     this->threads.insert(Photo::getKey(album), status);
                     this->photosUpdate++;
                     break;
@@ -430,6 +470,8 @@ PhotoList ServiceMgr::getPhotos(const Album& album, const bool isNeedUpdate, con
 
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "() Loaded " << ret.length() << " photos for album " << album.albumId;
 
+    filterManager_->filterList(ret);
+
     if (useSignal)
     {
         emit this->updatePhotoList(album.accountId, album.ownerId, album.albumId, ret, this->photosUpdate > 0? false: true);
@@ -438,11 +480,11 @@ PhotoList ServiceMgr::getPhotos(const Album& album, const bool isNeedUpdate, con
     return ret;
 }
 
-PhotoList ServiceMgr::getPhotos(const Photo &curPhoto, const bool isNeedUpdate, const bool useSignal)
+PhotoList ServiceMgr::getPhotos(const Photo &curPhoto, const bool isNeedUpdate, const bool useSignal, const bool loadIcons)
 {
     PhotoList ret;
 
-    qDebug() << "Load photo list from cache for " << curPhoto.albumId;
+    qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "Load photo list from cache for " << curPhoto.albumId;
 
     ret = Photo::loadPhotoList(curPhoto.accountId, curPhoto.ownerId, curPhoto.albumId);
     this->cleanThreads();
@@ -454,13 +496,15 @@ PhotoList ServiceMgr::getPhotos(const Photo &curPhoto, const bool isNeedUpdate,
                 qDebug() << "Download photo list for " << curPhoto.albumId;
                 if (this->threads.contains(Photo::getKey(curPhoto)) || !this->accounts.at(i)->isNetworkEnabled)
                     return ret;
-                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getPhotos, curPhoto.ownerId, curPhoto.albumId);
+                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getPhotos, curPhoto.ownerId, curPhoto.albumId, loadIcons);
                 this->threads.insert(Photo::getKey(curPhoto), status);
                 this->photosUpdate++;
             }
         }
     }
 
+    filterManager_->filterList(ret);
+
     if (useSignal)
     {
         emit this->updatePhotoList(curPhoto.accountId, curPhoto.ownerId, curPhoto.albumId, ret, this->photosUpdate > 0? false: true);
@@ -479,10 +523,12 @@ void ServiceMgr::gotPhotoList(QString accountId, QString friendId, QString album
         this->photosUpdate = 0;
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ <<"() islastUpdate=" << isLastUpdate << ", photosUpdate=" << photosUpdate;
 
+    filterManager_->filterList(list);
+
     emit updatePhotoList(accountId, friendId, albumId, list, photosUpdate > 0 ? false : true);
 }
 
-MessageList ServiceMgr::getInboxMessages(bool isNeedUpdate, bool useSignal)
+MessageList ServiceMgr::getMessages(bool isNeedUpdate, bool useSignal)
 {
     MessageList ret;
 
@@ -493,27 +539,35 @@ MessageList ServiceMgr::getInboxMessages(bool isNeedUpdate, bool useSignal)
     for (int i = 0; i < this->accounts.length(); i++) {
         if (isServiceFiltered(accounts[i])) continue;
 
-        MessageList curList = this->accounts.at(i)->getInboxMessageList();
+        MessageList curList = this->accounts.at(i)->getMessageList();
         ret.append(curList);
+
+        // drafts
+        MessageList draftList = this->accounts.at(i)->getDraftMessages();
+        ret.append(draftList);
+
         if (isNeedUpdate || curList.isEmpty()) {
-            QString threadId = QString("getInbox") + this->accounts[i]->transport->accountId;
+            QString threadId = QString("getMessages") + this->accounts[i]->transport->accountId;
+
             // check that thread shouldn't already running
             if (!this->threads.contains(threadId) && this->accounts.at(i)->isNetworkEnabled) {
                 // add thread to list
-                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getInbox);
+                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getMessages);
                 this->threads.insert(threadId, status);
-                this->inboxMessagesUpdate++;
+                this->messagesUpdate++;
             }
         }
     }
 
+    filterManager_->filterList(ret);
+
     if (useSignal)
-        emit this->updateInboxMessageList(ret, this->inboxMessagesUpdate > 0 ? false: true);
+        emit this->updateMessageList(ret, this->messagesUpdate > 0 ? false: true);
 
     return ret;
 }
 
-void ServiceMgr::gotInboxMessageList(QString accountId, MessageList list, bool isLastUpdate)
+void ServiceMgr::gotMessageList(QString accountId, MessageList list, bool isLastUpdate)
 {
     // create list of merged lists of messages
     MessageList ret;
@@ -523,87 +577,44 @@ void ServiceMgr::gotInboxMessageList(QString accountId, MessageList list, bool i
     for (int i = 0; i < this->accounts.length(); i++) {
         if (isServiceFiltered(accounts[i])) continue;
         if (this->accounts[i]->transport->accountId == accountId) {
-            this->accounts[i]->setInboxMessageList(list);
+            this->accounts[i]->setMessageList(list);
             ret.append(list);
             qDebug() << "Add to messages " << list.length() << ". Total:" << ret.length();
         } else {
-            MessageList lst = this->accounts[i]->getInboxMessageList();
+            MessageList lst = this->accounts[i]->getMessageList();
             ret.append(lst);
             qDebug() << "Add to messages " << lst.length() << ". Total:" << ret.length();
         }
     }
 
     if (isLastUpdate)
-        this->inboxMessagesUpdate--;
-    qDebug() << "islastUpdate=" << isLastUpdate << ", inboxMessagesUpdate=" << inboxMessagesUpdate;
+        this->messagesUpdate--;
+    qDebug() << "islastUpdate=" << isLastUpdate << ", messagesUpdate=" << messagesUpdate;
 
-    emit updateInboxMessageList(ret, (this->inboxMessagesUpdate > 0 ? false: true));
+    filterManager_->filterList(ret);
+
+    emit updateMessageList(ret, (this->messagesUpdate > 0 ? false: true));
 }
 
-MessageList ServiceMgr::getOutboxMessages(bool isNeedUpdate, bool useSignal)
-{
-    MessageList ret;
-
-    qDebug() << __FILE__ << ":" << __FUNCTION__;
-
-    this->cleanThreads();
-
-    for (int i = 0; i < this->accounts.length(); i++) {
-        MessageList curList = this->accounts.at(i)->getOutboxMessageList();
-        ret.append(curList);
-        if (isNeedUpdate || curList.isEmpty()) {
-            QString threadId = QString("getOutbox") + this->accounts[i]->transport->accountId;
-            // check that thread shouldn't already running
-            if (!this->threads.contains(threadId) && this->accounts.at(i)->isNetworkEnabled) {
-                // add thread to list
-                QFuture<void> status = QtConcurrent::run(this->accounts[i]->transport, &QTransport::getOutbox);
-                this->threads.insert(threadId, status);
-                this->outboxMessagesUpdate++;
-            }
-        }
-    }
-
-    if (useSignal)
-        emit this->updateOutboxMessageList(ret, this->outboxMessagesUpdate > 0 ? false: true);
-
-    return ret;
-}
-
-void ServiceMgr::gotOutboxMessageList(QString accountId, MessageList list, bool isLastUpdate)
-{
-    // create list of merged lists of messages
-    MessageList ret;
-
-    qDebug() << __FILE__ << __FUNCTION__ << ": " << list.length();
-
-    for (int i = 0; i < this->accounts.length(); i++) {
-        if (this->accounts[i]->transport->accountId == accountId) {
-            this->accounts[i]->setOutboxMessageList(list);
-            ret.append(list);
-            qDebug() << "Add to messages " << list.length() << ". Total:" << ret.length();
-        } else {
-            MessageList lst = this->accounts[i]->getOutboxMessageList();
-            ret.append(lst);
-            qDebug() << "Add to messages " << lst.length() << ". Total:" << ret.length();
-        }
-    }
-
-    if (isLastUpdate)
-        this->outboxMessagesUpdate--;
-    qDebug() << "islastUpdate=" << isLastUpdate << ", outboxMessagesUpdate=" << outboxMessagesUpdate;
-
-    emit updateOutboxMessageList(ret, (this->outboxMessagesUpdate > 0 ? false: true));
-}
-
-void ServiceMgr::deleteMessage(const Message& msg)
+bool ServiceMgr::deleteMessage(const Message& msg)
 {
     for (int i = 0; i < this->accounts.length(); i++) {
         if (msg.accountId == this->accounts[i]->transport->accountId) {
             qDebug() << "Deleting message: " << msg.messageId;
 
-            this->accounts[i]->transport->deleteMessage(msg);
+            return this->accounts[i]->transport->deleteMessage(msg);
         }
     }
+    return false;
+}
+
+bool ServiceMgr::canSendMessage(const QString &accountId)
+{
+    for (int i = 0; i < this->accounts.length(); i++) {
+        if (accountId == this->accounts.at(i)->transport->accountId)
+            return this->accounts.at(i)->transport->checkFunction(CLASS_MESSAGES, SEND_MESSAGE);
+    }
+    return false;
 }
 
 bool ServiceMgr::sendMessage(const QString &accountId, const QString &ownerId, const QString &title, const QString &message)
@@ -649,6 +660,8 @@ PhotoCommentList ServiceMgr::getComments(const Photo& curPhoto, const bool isNee
         }
     }
 
+    filterManager_->filterList(ret);
+
     if (useSignal)
         emit this->updatePhotoCommentList(curPhoto.photoId, ret);
 
@@ -659,6 +672,7 @@ void ServiceMgr::gotComments(QString accountId, QString ownerId, QString albumId
 {
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): photoId=" << photoId << " has comments=" << list.length();
     Photo::setPhotoComments(list, accountId, ownerId, albumId, photoId);
+    filterManager_->filterList(list);
     emit this->updatePhotoCommentList(photoId, list);
 }
 
@@ -673,12 +687,16 @@ bool ServiceMgr::sendComment(const Photo& curPhoto, const QString& comment)
 
 void ServiceMgr::gotProfile(QString accountId, QString reqOwnerId, Friend profile)
 {
+    Friend ret = profile;
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): reqOwnerId=" << reqOwnerId;
     if (reqOwnerId.isEmpty()) {
         for (int i = 0; i < this->accounts.length(); i++) {
             if (this->accounts.at(i)->accountId().compare(accountId) == 0) {
+                bool isNE = this->accounts.at(i)->isNetworkEnabled;
                 this->accounts.at(i)->setProfile(profile);
-                emit updateAccounts(this->accounts.at(i)->accountId(), this->accounts);
+                if (!isNE)
+                    emit updateAccounts(this->accounts.at(i)->accountId(), this->accounts);
+                ret = this->getMyProfile(false);
                 break;
             }
         }
@@ -742,7 +760,8 @@ void ServiceMgr::deleteAccount(Account *oldAcc)
 
 QList<DriverInfo*> ServiceMgr::getDrivers()
 {
-    QList<DriverInfo*> ret;
+    if (!cachedDriverList.isEmpty())
+        return this->cachedDriverList;
 
     QDir dir;
     dir.setFilter(QDir::Dirs|QDir::NoDotAndDotDot);
@@ -765,14 +784,14 @@ QList<DriverInfo*> ServiceMgr::getDrivers()
                     DriverInfo *curDr = QTransport::getDriverInfo(file.filePath());
                     if (curDr != NULL) {
                         qDebug() << "found driver " << curDr->name;
-                        ret.append(curDr);
+                        this->cachedDriverList.append(curDr);
                     }
                 }
             }
         }
     }
 
-    return ret;
+    return this->cachedDriverList;
 }
 
 PhotoList ServiceMgr::getPhotosForAlbum(Photo curPhoto)
@@ -816,7 +835,7 @@ PhotoList ServiceMgr::getPhotosForAlbum(Account *curAcc, Photo curPhoto)
 
     // try to load album if it not found
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): Can't found cached photos for album " << curPhoto.albumId;
-    return this->getPhotos(curPhoto, false, false);
+    return this->getPhotos(curPhoto, false, false, false);
 }
 
 void ServiceMgr::downloadPhotos(Photo startPhoto, int nearest) {
@@ -931,11 +950,8 @@ void ServiceMgr::gotErrorMsg(QString accountId, QErrorMessage msg, QTransport::A
     case QTransport::sendCommentAction:
         prefix += tr("\"Send comment\"");
         break;
-    case QTransport::getInboxMessagesAction:
-        prefix += tr("\"Get message inbox\"");
-        break;
-    case QTransport::getOutboxMessagesAction:
-        prefix += tr("\"Get message outbox\"");
+    case QTransport::getMessagesAction:
+        prefix += tr("\"Get list of messages\"");
         break;
     case QTransport::sendMessageAction:
         prefix += tr("\"Send message\"");
@@ -1004,8 +1020,12 @@ void ServiceMgr::clearCache()
 
 Friend ServiceMgr::getProfile(const QString& accountId, const QString& ownerId, const bool isNeedUpdate, const bool useSignal, const bool isFullProfile)
 {
+    qDebug() << __FILE__ <<":" << __LINE__ <<":" << __FUNCTION__ << ": accountId=" << accountId << "; isNeedUpdate=" << isNeedUpdate << "; isFullProfile=" << isFullProfile;
+    Account *acc = this->account(accountId);
+    assert(acc);
     QString service = this->account(accountId)->serviceName();
     bool isFound = false;
+    bool hasFullProfile = false;
     Friend ret;
 
     // step 1. check downloaded full profiles from all accounts
@@ -1018,6 +1038,7 @@ Friend ServiceMgr::getProfile(const QString& accountId, const QString& ownerId,
         {
             ret = nonFr;
             isFound = true;
+            hasFullProfile = true;
             break;
         }
     }
@@ -1059,7 +1080,7 @@ Friend ServiceMgr::getProfile(const QString& accountId, const QString& ownerId,
     qDebug() << __FILE__ <<":" <<__LINE__ << ":" << __FUNCTION__ << "(): step2 isFound" << isFound;
 
     // step 3. download full profile if it isn't found or need update
-    if (!isFound || isNeedUpdate || isFullProfile)
+    if (!isFound || isNeedUpdate || (isFullProfile && !hasFullProfile))
     {
         this->cleanThreads();
 
@@ -1083,6 +1104,18 @@ Friend ServiceMgr::getProfile(const PhotoComment& comment, const bool isNeedUpda
     return this->getProfile(comment.accountId, comment.senderId, isNeedUpdate, useSignal, false);
 }
 
+Friend ServiceMgr::getMyProfile(bool isNeedUpdate)
+{
+    if (this->accounts.length() > 0)
+    {
+        Friend fd = this->accounts.at(0)->getProfile(isNeedUpdate);
+        for (int i = 1; i < this->accounts.length(); i++)
+            fd.addProfile(this->accounts.at(i)->getProfile(isNeedUpdate), false);
+        return fd;
+    }
+    return Friend();
+}
+
 QEventFeedList ServiceMgr::getFeed(QEventFeed::FeedType type, bool isNeedUpdate, bool useSignal)
 {
     return this->getFeed(NULL, type, isNeedUpdate, useSignal);
@@ -1148,11 +1181,56 @@ void ServiceMgr::gotEventFeed(QString accountId, QEventFeedList list, QEventFeed
 void ServiceMgr::changeFilteredService(DriverInfo* driverInfo)
 {
     filteredDriver = driverInfo;
-    getFriends(false, true);
-    getInboxMessages(false, true);
+    this->cachedFriendList.clear();
+
+    updateData();
+}
+
+void ServiceMgr::updateData(int type)
+{
+    bool all = (type == -1);
+
+    if (all || type == qMetaTypeId<Friend>()) {
+        getFriends(false, true);
+    }
+
+    if (all || type == qMetaTypeId<Message>()) {
+        getMessages(false, true);
+    }
 }
 
 bool ServiceMgr::isServiceFiltered(const Account* acc) const
 {
     return filteredDriver && acc->serviceName() != filteredDriver->serviceName;
 }
+
+void ServiceMgr::createFilter()
+{
+    serviceFilter_ = new ServiceFilter(this, this);
+    connect(serviceFilter_, SIGNAL(serviceSelected(DriverInfo*)), SLOT(changeFilteredService(DriverInfo*)));
+
+    filterManager_ = new FilterManager(this);
+    filterManager_->setObjectName("Main filter manager");
+
+    connect(filterManager_, SIGNAL(stateChanged(int)), SLOT(updateData(int)));
+
+    filterManager_->registerFilterableType<Friend>();
+    filterManager_->registerFilterableType<Album>();
+    filterManager_->registerFilterableType<Message>();
+    filterManager_->registerFilterableType<Photo>();
+
+    filterManager_->addFilter(new FilterFriendOnline(filterManager_));
+    filterManager_->addFilter(new FilterFriendGender(filterManager_));
+    filterManager_->addFilter(new FilterMessageReaded(filterManager_));
+    filterManager_->addFilter(new FilterMessageType(this, filterManager_));
+}
+
+FilterManager* ServiceMgr::filterManager() const
+{
+    return filterManager_;
+}
+
+ServiceFilter* ServiceMgr::serviceFilter() const
+{
+    return serviceFilter_;
+}
