@@ -27,6 +27,9 @@
 #include "utils/utils.h"
 #include "mysocials_global.h"
 
+class ServiceFilter;
+class FilterManager;
+
 /**
   \brief File name for list of accounts storage.
   */
@@ -129,6 +132,8 @@ public:
       */
     Friend getProfile(const PhotoComment& comment, const bool isNeedUpdate, const bool useSignal);
 
+    Friend getMyProfile(bool isNeedUpdate);
+
     /**
      \brief Get list of friends.
 
@@ -191,7 +196,7 @@ public:
 
      \return Stored list of images. Newest list will be sent using \sa updatePhotoList signal.
      */
-    PhotoList getPhotos(const Album& curAlbum, const bool isNeedUpdate, const bool useSignal);
+    PhotoList getPhotos(const Album& curAlbum, const bool isNeedUpdate, const bool useSignal, const bool loadIcons);
 
     /**
      \brief Get content of album.
@@ -207,7 +212,7 @@ public:
 
      \return Stored list of images. Newest list will be sent using \sa updatePhotoList signal.
      */
-    PhotoList getPhotos(const Photo& curPhoto, const bool isNeedUpdate, const bool useSignal);
+    PhotoList getPhotos(const Photo& curPhoto, const bool isNeedUpdate, const bool useSignal, const bool loadIcons);
 
     /**
      \brief Get list of comments for specified image.
@@ -234,7 +239,7 @@ public:
     bool sendComment(const Photo& curPhoto, const QString& comment);
 
     /**
-      \brief Get list of messages from Inbox folder.
+      \brief Get list of messages.
 
       \param isNeedUpdate True if need to get new message list, otherwise - false.
 
@@ -242,18 +247,7 @@ public:
 
       \return Stored list of messages from Inbox folder. Newest list will be sent using \sa updateInboxMessageList signal.
       */
-    MessageList getInboxMessages(const bool isNeedUpdate, const bool useSignal);
-
-    /**
-      \brief Get list of messages from Outbox folder.
-
-      \param isNeedUpdate True if need to get new message list, otherwise - false.
-
-      \param useSignal True if return must be sended as signal, otherwise - false.
-
-      \return Stored list of messages from Outbox folder. Newest list will be sent using \sa updateOutboxMessageList signal.
-      */
-    MessageList getOutboxMessages(const bool isNeedUpdate, const bool useSignal);
+    MessageList getMessages(const bool isNeedUpdate, const bool useSignal);
 
     /**
       \brief Delete message from service.
@@ -265,7 +259,9 @@ public:
 
       \param msg Deleted message.
       */
-    void deleteMessage(const Message& msg);
+    bool deleteMessage(const Message& msg);
+
+    bool canSendMessage(const QString& accountId);
 
     /**
       \brief Sends private message to friend on service.
@@ -454,6 +450,9 @@ public:
 
     int getNumThreadsFeedUpdate() const { return this->feedsUpdate;}
 
+    FilterManager* filterManager() const;
+    ServiceFilter* serviceFilter() const;
+
 private:
     /**
      \brief List of user accounts.
@@ -504,13 +503,19 @@ private:
 
     int feedsUpdate; /**< \brief Number of feeds update processes.  */
 
-    int inboxMessagesUpdate; /**< \brief Number of Inbox folder messages update processes.  */
+    int messagesUpdate; /**< \brief Number of Inbox folder messages update processes.  */
 
-    int outboxMessagesUpdate; /**< \brief Number of Outbox folder update processes.  */
-
-    // Current filtered friver
-    DriverInfo* filteredDriver;
     bool isSkipFriendListUpdate; /**< \brief Skip unwanted friend list update flag. */
+    FriendList cachedFriendList; /**< \brief The cached friend list. Used for optimize sorting and merging processes. */
+
+    QList<DriverInfo*> cachedDriverList; /**< \brief The cached drivers list. */
+
+
+    // Filters
+    DriverInfo* filteredDriver;
+    ServiceFilter* serviceFilter_;
+    FilterManager* filterManager_;
+    void createFilter();
 
     // Check whether AccountInfo filtered
     bool isServiceFiltered(const Account* info) const;
@@ -573,30 +578,17 @@ signals:
     void updatePhotoCommentList(QString photoId, PhotoCommentList list);
 
     /**
-     * @brief Update Inbox folder signal.
+     * @brief Update message folder signal.
      *
-     This signal sent when content of inbox folder was download successfully.
+     This signal sent when content of message folder was download successfully.
 
-     \sa getInboxMessages()
+     \sa getMessages()
 
      * @param list The list of messages.
 
      * @param isLastUpdate True if it is last signal, otherwise - false.
      */
-    void updateInboxMessageList(MessageList list, bool isLastUpdate);
-
-    /**
-     * @brief Update Outbox folder signal.
-     *
-     This signal sent when content of outbox folder was download successfully.
-
-     \sa getInboxMessages()
-
-     * @param list The list of messages.
-
-     * @param isLastUpdate True if it is last signal, otherwise - false.
-     */
-    void updateOutboxMessageList(MessageList list, bool isLastUpdate);
+    void updateMessageList(MessageList list, bool isLastUpdate);
 
     /**
      * @brief Update account list signal.
@@ -710,15 +702,7 @@ private slots:
      * @param MessageList
      * @param isLastUpdate
      */
-    void gotInboxMessageList(QString accountId, MessageList, bool isLastUpdate);
-    /**
-     * @brief
-     *
-     * @param accountId
-     * @param MessageList
-     * @param isLastUpdate
-     */
-    void gotOutboxMessageList(QString accountId, MessageList, bool isLastUpdate);
+    void gotMessageList(QString accountId, MessageList, bool isLastUpdate);
     /**
      * @brief
      *
@@ -767,7 +751,7 @@ private slots:
 
 public slots:
     void changeFilteredService(DriverInfo* driverInfo);
-
+    void updateData(int type = -1);
     /**
      * @brief
      *
