@@ -23,6 +23,8 @@ public:
     void setText(QString text);
     void setRefreshIcon(QIcon icon);
     void setBackIcon(QIcon icon);
+    void setInfoWidget(QWidget *infoWidget);
+    void setBackVisible(bool visible);
 
 private:
     QPushButton *back;
@@ -30,6 +32,8 @@ private:
     QLabel *icon;
     QLabel *text;
 
+    QWidget *infoWidget;
+
 protected:
     void mousePressEvent(QMouseEvent *);
 
@@ -37,6 +41,11 @@ signals:
     void clicked();
     void backPressed();
     void refreshPressed();
+
+public slots:
+    void hideInfoWidget();
+    void showInfoWidget();
+    void toggleInfoWidget();
 };
 
 #endif // QTOPPANEL_H
