@@ -1,6 +1,97 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="ru_RU">
+<context>
+    <name>AlbumInfoWidget</name>
+    <message>
+        <source>Title</source>
+        <translation type="obsolete">Название</translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="obsolete">Описание</translation>
+    </message>
+    <message>
+        <source>Creation time</source>
+        <translation type="obsolete">Создан</translation>
+    </message>
+    <message>
+        <source>Update time</source>
+        <translation type="obsolete">Обновлен</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/albuminfowidget.cpp" line="18"/>
+        <source>Title:</source>
+        <translation>Название:</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/albuminfowidget.cpp" line="21"/>
+        <source>Description:</source>
+        <translation>Описание:</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/albuminfowidget.cpp" line="24"/>
+        <source>Created:</source>
+        <translation>Создан:</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/albuminfowidget.cpp" line="27"/>
+        <source>Updated:</source>
+        <translation>Обновлен:</translation>
+    </message>
+</context>
+<context>
+    <name>FilterFriendGender</name>
+    <message>
+        <location filename="../src/filter/filterfriendgender.cpp" line="41"/>
+        <source>Male</source>
+        <translation>Мужской</translation>
+    </message>
+    <message>
+        <location filename="../src/filter/filterfriendgender.cpp" line="53"/>
+        <source>Female</source>
+        <translation>Женский</translation>
+    </message>
+</context>
+<context>
+    <name>FilterFriendOnline</name>
+    <message>
+        <location filename="../src/filter/filterfriendonline.cpp" line="29"/>
+        <source>Online</source>
+        <translation>В сети</translation>
+    </message>
+</context>
+<context>
+    <name>FilterMessageReaded</name>
+    <message>
+        <location filename="../src/filter/filtermessagereaded.cpp" line="31"/>
+        <source>New</source>
+        <translation>Новые</translation>
+    </message>
+</context>
+<context>
+    <name>FilterMessageType</name>
+    <message>
+        <location filename="../src/filter/filtermessagetype.cpp" line="72"/>
+        <source>All messages</source>
+        <translation>Все сообщения</translation>
+    </message>
+    <message>
+        <location filename="../src/filter/filtermessagetype.cpp" line="76"/>
+        <source>Inbox</source>
+        <translation>Входящие</translation>
+    </message>
+    <message>
+        <location filename="../src/filter/filtermessagetype.cpp" line="81"/>
+        <source>Sent</source>
+        <translation>Отправленные</translation>
+    </message>
+    <message>
+        <location filename="../src/filter/filtermessagetype.cpp" line="85"/>
+        <source>Drafts</source>
+        <translation>Черновики</translation>
+    </message>
+</context>
 <context>
     <name>Friend</name>
     <message>
@@ -21,8 +112,8 @@
         <translation type="obsolete">Друзья</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="94"/>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="574"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="104"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="472"/>
         <source>People (%1)</source>
         <translation>Друзья (%1)</translation>
     </message>
@@ -31,18 +122,17 @@
         <translation type="obsolete">Новости</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="99"/>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="1131"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="113"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="1000"/>
         <source>News (%1)</source>
         <translation>Обновления (%1)</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="123"/>
         <source>Type a name...</source>
-        <translation>Введите имя...</translation>
+        <translation type="obsolete">Введите имя...</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="330"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="326"/>
         <source>%1 photo(s)</source>
         <translation>
             <numerusform>%1 изображение</numerusform>
@@ -51,22 +141,22 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="332"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="328"/>
         <source> Updated: </source>
         <translation> Обновлен: </translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="351"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="353"/>
         <source>Album(s):</source>
         <translation>Альбом(ы):</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="402"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="419"/>
         <source>Photo(s):</source>
         <translation>Изображения:</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="415"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="430"/>
         <source>%1 photo(s):</source>
         <translation>
             <numerusform>%1 изображение:</numerusform>
@@ -75,47 +165,51 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="464"/>
         <source>No Friends</source>
-        <translation>Нет друзей</translation>
+        <translation type="obsolete">Нет друзей</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="466"/>
         <source>Download friend list</source>
-        <translation>Загрузка списка друзей</translation>
+        <translation type="obsolete">Загрузка списка друзей</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="507"/>
         <source>Online</source>
-        <translation>В сети</translation>
+        <translation type="obsolete">В сети</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="636"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="321"/>
+        <source>Untitled album</source>
+        <translation>Безымянный альбом</translation>
+    </message>
+    <message>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="524"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="1084"/>
         <source>No albums</source>
         <translation>Нет альбомов</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="638"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="526"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="1082"/>
         <source>Download albums</source>
         <translation>Загрузка списка альбомов</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="756"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="644"/>
         <source>No images</source>
         <translation>Нет изображений</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="758"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="646"/>
         <source>Download images</source>
         <translation>Загрузка изображений</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="1044"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="933"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/panels/imagebrowserpanel.cpp" line="1044"/>
+        <location filename="../src/panels/imagebrowserpanel.cpp" line="933"/>
         <source>Unknown window state</source>
         <translation>Неопределенное состояние окна</translation>
     </message>
@@ -128,22 +222,38 @@
         <translation>Форма</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagebrowser.ui" line="74"/>
+        <location filename="../src/widgets/messagebrowser.cpp" line="56"/>
         <source>Title:</source>
         <translation>Заголовок:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagebrowser.ui" line="88"/>
+        <location filename="../src/widgets/messagebrowser.cpp" line="61"/>
         <source>From:</source>
         <translation>От кого:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagebrowser.ui" line="102"/>
+        <location filename="../src/widgets/messagebrowser.cpp" line="185"/>
+        <source>Date: </source>
+        <translation>Дата: </translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/messagebrowser.cpp" line="189"/>
+        <source>To: </source>
+        <translation>Кому: </translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/messagebrowser.cpp" line="193"/>
+        <location filename="../src/widgets/messagebrowser.cpp" line="196"/>
+        <source>From: </source>
+        <translation>От кого: </translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/messagebrowser.cpp" line="59"/>
         <source>Date:</source>
         <translation>Дата:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagebrowser.ui" line="123"/>
+        <location filename="../src/widgets/messagebrowser.cpp" line="63"/>
         <source>To:</source>
         <translation>Кому:</translation>
     </message>
@@ -156,22 +266,35 @@
         <translation>Форма</translation>
     </message>
     <message>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="130"/>
         <source>Title</source>
-        <translation>Тема</translation>
+        <translation type="obsolete">Тема</translation>
     </message>
     <message>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="130"/>
         <source>Date</source>
-        <translation>Дата</translation>
+        <translation type="obsolete">Дата</translation>
     </message>
     <message>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="646"/>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="88"/>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="176"/>
+        <source>Messages (%1)</source>
+        <translation>Сообщения (%1)</translation>
+    </message>
+    <message>
+        <source>News</source>
+        <translation type="obsolete">Новости</translation>
+    </message>
+    <message>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="98"/>
+        <source>News (%1)</source>
+        <translation>Обновления (%1)</translation>
+    </message>
+    <message>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="371"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/panels/messagebrowserpanel.cpp" line="646"/>
+        <location filename="../src/panels/messagebrowserpanel.cpp" line="371"/>
         <source>Unknown window state</source>
         <translation>Неопределенное состояние окна</translation>
     </message>
@@ -194,17 +317,17 @@
         <translation>Кому:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagecomposer.cpp" line="27"/>
+        <location filename="../src/widgets/messagecomposer.cpp" line="29"/>
         <source>Send</source>
         <translation>Отправить</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagecomposer.cpp" line="30"/>
+        <location filename="../src/widgets/messagecomposer.cpp" line="33"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="../src/widgets/messagecomposer.cpp" line="128"/>
+        <location filename="../src/widgets/messagecomposer.cpp" line="120"/>
         <source>Re: %1</source>
         <translation></translation>
     </message>
@@ -223,48 +346,89 @@
     </message>
     <message>
         <location filename="../src/widgets/profilebrowser.ui" line="78"/>
+        <location filename="../src/widgets/profilebrowser.ui" line="91"/>
+        <source>TextLabel</source>
+        <translation></translation>
+    </message>
+    <message>
         <source>First name:</source>
-        <translation>Имя:</translation>
+        <translation type="obsolete">Имя:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="95"/>
         <source>Nick:</source>
-        <translation>Прозвище:</translation>
+        <translation type="obsolete">Прозвище:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="112"/>
         <source>Last name:</source>
-        <translation>Фамилия:</translation>
+        <translation type="obsolete">Фамилия:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="126"/>
         <source>Gender:</source>
-        <translation>Пол:</translation>
+        <translation type="obsolete">Пол:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="140"/>
         <source>Birthday:</source>
-        <translation>Дата рождения:</translation>
+        <translation type="obsolete">Дата рождения:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="154"/>
         <source>Mobile phone:</source>
-        <translation>Мобильный телефон:</translation>
+        <translation type="obsolete">Мобильный телефон:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="168"/>
         <source>Home phone:</source>
-        <translation>Стационарный телефон:</translation>
+        <translation type="obsolete">Стационарный телефон:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="182"/>
         <source>City:</source>
-        <translation>Город:</translation>
+        <translation type="obsolete">Город:</translation>
     </message>
     <message>
-        <location filename="../src/widgets/profilebrowser.ui" line="196"/>
         <source>Country:</source>
-        <translation>Страна:</translation>
+        <translation type="obsolete">Страна:</translation>
+    </message>
+    <message>
+        <source>Places</source>
+        <translation type="obsolete">Местоположение</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="114"/>
+        <source>General</source>
+        <translation>Основная информация</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="117"/>
+        <source>Nickname: </source>
+        <translation>Прозвище: </translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="120"/>
+        <source>Birthday: </source>
+        <translation>День рождения: </translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="124"/>
+        <source>Gender: </source>
+        <translation>Пол: </translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="129"/>
+        <source>Place</source>
+        <translation>Местоположение</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.cpp" line="144"/>
+        <source>Contacts</source>
+        <translation>Контакты</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.h" line="87"/>
+        <source>male</source>
+        <translation>мужской</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/profilebrowser.h" line="88"/>
+        <source>female</source>
+        <translation>женский</translation>
     </message>
 </context>
 <context>
@@ -275,57 +439,58 @@
         <translation>Форма</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="52"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="55"/>
         <source>Albums</source>
         <translation>Альбомы</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="61"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="64"/>
         <source>Messages</source>
         <translation>Сообщения</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="70"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="73"/>
         <source>Send message</source>
         <translation>Отправить сообщение</translation>
     </message>
+    <message>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="95"/>
+        <source>News (%1)</source>
+        <translation>Обновления (%1)</translation>
+    </message>
     <message>
         <source>People</source>
         <translation type="obsolete">Друзья</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="79"/>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="374"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="86"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="214"/>
         <source>People (%1)</source>
         <translation>Друзья (%1)</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="83"/>
         <source>News</source>
-        <translation>Новости</translation>
+        <translation type="obsolete">Новости</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="102"/>
         <source>Type a name...</source>
-        <translation>Введите имя...</translation>
+        <translation type="obsolete">Введите имя...</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="279"/>
         <source>No Friends</source>
-        <translation>Нет друзей</translation>
+        <translation type="obsolete">Нет друзей</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="281"/>
         <source>Download friend list</source>
-        <translation>Загрузка списка друзей</translation>
+        <translation type="obsolete">Загрузка списка друзей</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="434"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="288"/>
         <source>Error occured</source>
         <translation>Произошла ошибка</translation>
     </message>
     <message>
-        <location filename="../src/panels/profilebrowserpanel.cpp" line="434"/>
+        <location filename="../src/panels/profilebrowserpanel.cpp" line="288"/>
         <source>Unknown window state</source>
         <translation>Неопределенное состояние окна</translation>
     </message>
@@ -346,39 +511,100 @@
         <translation>Список драйверов</translation>
     </message>
 </context>
+<context>
+    <name>QFriendDelegate</name>
+    <message>
+        <location filename="../src/widgets/friends/qfrienddelegate.cpp" line="86"/>
+        <source>online</source>
+        <translation>в сети</translation>
+    </message>
+</context>
+<context>
+    <name>QFriendListWidget</name>
+    <message>
+        <location filename="../src/widgets/friends/qfriendlistwidget.ui" line="14"/>
+        <source>Form</source>
+        <translation>Форма</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="21"/>
+        <source>Type a name...</source>
+        <translation>Введите имя...</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="56"/>
+        <source>Me</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>QImageViewer</name>
     <message>
-        <location filename="../src/widgets/qimageviewer.cpp" line="93"/>
+        <location filename="../src/widgets/qimageviewer.cpp" line="95"/>
         <source>Comments</source>
         <translation>Комментарии</translation>
     </message>
     <message>
-        <location filename="../src/widgets/qimageviewer.cpp" line="94"/>
+        <location filename="../src/widgets/qimageviewer.cpp" line="96"/>
         <source>Refresh comments</source>
         <translation>Обновить комментарии</translation>
     </message>
     <message>
-        <location filename="../src/widgets/qimageviewer.cpp" line="96"/>
+        <location filename="../src/widgets/qimageviewer.cpp" line="98"/>
         <source>Add comment</source>
         <translation>Добавить комментарий</translation>
     </message>
     <message>
-        <location filename="../src/widgets/qimageviewer.cpp" line="214"/>
+        <location filename="../src/widgets/qimageviewer.cpp" line="231"/>
         <source>Image Viewer</source>
         <translation>Программа просмотра изображений</translation>
     </message>
     <message>
-        <location filename="../src/widgets/qimageviewer.cpp" line="215"/>
+        <location filename="../src/widgets/qimageviewer.cpp" line="232"/>
         <source>Cannot load %1.</source>
         <translation>Не удалось загрузить %1.</translation>
     </message>
     <message>
-        <location filename="../src/widgets/qimageviewer.cpp" line="248"/>
+        <location filename="../src/widgets/qimageviewer.cpp" line="265"/>
         <source>Downloading image...</source>
         <translation>Загрузка изображения...</translation>
     </message>
 </context>
+<context>
+    <name>QMessageListModel</name>
+    <message>
+        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="81"/>
+        <source>Title</source>
+        <translation>Тема</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="83"/>
+        <source>Date</source>
+        <translation>Дата</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="85"/>
+        <source>From/To</source>
+        <translation>От/Кому</translation>
+    </message>
+</context>
+<context>
+    <name>QMessageListWidget</name>
+    <message>
+        <location filename="../src/widgets/messages/qmessagelistwidget.ui" line="14"/>
+        <source>Form</source>
+        <translation>Форма</translation>
+    </message>
+    <message>
+        <source>Type a name...</source>
+        <translation type="obsolete">Введите имя...</translation>
+    </message>
+    <message>
+        <location filename="../src/widgets/messages/qmessagelistwidget.cpp" line="22"/>
+        <source>Type a title...</source>
+        <translation>Введите тему сообщения...</translation>
+    </message>
+</context>
 <context>
     <name>QPhotoUploader</name>
     <message>
@@ -507,112 +733,122 @@
     </message>
     <message>
         <location filename="../src/qtransport.cpp" line="289"/>
-        <location filename="../src/qtransport.cpp" line="1108"/>
+        <location filename="../src/qtransport.cpp" line="1157"/>
         <source>Bad response from driver</source>
         <translation>Некорректный ответ от драйвера</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="342"/>
+        <location filename="../src/qtransport.cpp" line="351"/>
         <source>Unsupported method was called</source>
         <translation>Вызван неподдерживаемый метод</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="343"/>
+        <location filename="../src/qtransport.cpp" line="352"/>
         <source>This method didn&apos;t supported by selected driver</source>
         <translation>Метод не поддерживается выбранным драйвером</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="819"/>
+        <location filename="../src/qtransport.cpp" line="863"/>
         <source>The friend or album identificators are not equal</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="820"/>
+        <location filename="../src/qtransport.cpp" line="864"/>
         <source>Incorrect identificators</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="1068"/>
+        <location filename="../src/qtransport.cpp" line="1117"/>
         <source>Can&apos;t read file to upload</source>
         <translation>Не удалось открыть отправляемый на сервис файл</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="1179"/>
+        <location filename="../src/qtransport.cpp" line="1228"/>
         <source>QTransport::downloadPhotoLost() with nearest &lt; 0</source>
         <translation>QTransport::downloadPhotoLost() с параметром nearest &lt; 0</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.cpp" line="1180"/>
+        <location filename="../src/qtransport.cpp" line="1229"/>
         <source>Wrong arguments of function</source>
         <translation>Неправильные аргументы функции</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="217"/>
+        <location filename="../src/qtransport.h" line="251"/>
         <source>Unable to save settings</source>
         <translation>Не удалось сохранить настройки</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="218"/>
+        <location filename="../src/qtransport.h" line="252"/>
         <source>Authorization problem</source>
         <translation>Проблема авторизации</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="219"/>
+        <location filename="../src/qtransport.h" line="253"/>
         <source>Authorization canceled</source>
         <translation>Авторизация прервана</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="220"/>
+        <location filename="../src/qtransport.h" line="254"/>
         <source>Unable to perform request</source>
         <translation>Невозможно выполнить запрос</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="221"/>
+        <location filename="../src/qtransport.h" line="255"/>
         <source>Server busy</source>
         <translation>Сервер занят</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="222"/>
+        <location filename="../src/qtransport.h" line="256"/>
         <source>One of the parameters missing or invalid</source>
         <translation>Один из параметров пропущен или неверен</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="223"/>
+        <location filename="../src/qtransport.h" line="257"/>
         <source>Captcha</source>
         <translation>Требуется ввод каптчи</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="224"/>
+        <location filename="../src/qtransport.h" line="258"/>
         <source>Bad response from server</source>
         <translation>Некорректный ответ от сервера</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="225"/>
+        <location filename="../src/qtransport.h" line="259"/>
         <source>Network problem</source>
         <translation>Проблема соединения с сервером</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="226"/>
+        <location filename="../src/qtransport.h" line="260"/>
         <source>Empty message</source>
         <translation>Пустое сообщение</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="227"/>
+        <location filename="../src/qtransport.h" line="261"/>
         <source>Operation prohibited by privacy</source>
         <translation>Операция запрещена приватностью</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="228"/>
+        <location filename="../src/qtransport.h" line="262"/>
         <source>Internal Server Error</source>
         <translation>Внутренняя ошибка сервера</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="229"/>
+        <location filename="../src/qtransport.h" line="263"/>
         <source>Can&apos;t save file</source>
         <translation>Не удалось сохранить файл</translation>
     </message>
     <message>
-        <location filename="../src/qtransport.h" line="232"/>
+        <location filename="../src/qtransport.h" line="264"/>
+        <source>male</source>
+        <translation>мужской</translation>
+    </message>
+    <message>
+        <location filename="../src/qtransport.h" line="265"/>
+        <source>female</source>
+        <translation>женский</translation>
+    </message>
+    <message>
+        <location filename="../src/qtransport.h" line="268"/>
         <source>Incorrect signature</source>
         <translation>Информация об авторизации неверная или устарела</translation>
     </message>
@@ -620,115 +856,117 @@
 <context>
     <name>ServiceFilter</name>
     <message>
-        <location filename="../src/widgets/filter/servicefilter.cpp" line="22"/>
         <source>All</source>
-        <translation>Все</translation>
+        <translation type="obsolete">Все</translation>
     </message>
 </context>
 <context>
     <name>ServiceMgr</name>
     <message>
-        <location filename="../src/servicemgr.cpp" line="878"/>
+        <location filename="../src/servicemgr.cpp" line="897"/>
         <source>During request </source>
         <translation>В ходе запроса </translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="893"/>
+        <location filename="../src/servicemgr.cpp" line="912"/>
         <source>&quot;Update list of friends&quot;</source>
         <translation>&quot;Обновление списка друзей&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="896"/>
+        <location filename="../src/servicemgr.cpp" line="915"/>
         <source>&quot;Delete friend from list&quot;</source>
         <translation>&quot;Удаление друга из списка&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="902"/>
+        <location filename="../src/servicemgr.cpp" line="921"/>
         <source>&quot;Update list of albums&quot;</source>
         <translation>&quot;Обновление списка альбомов&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="908"/>
+        <location filename="../src/servicemgr.cpp" line="927"/>
         <source>&quot;Update list of images&quot;</source>
         <translation>&quot;Обновление списка изображений&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="911"/>
+        <location filename="../src/servicemgr.cpp" line="930"/>
         <source>&quot;Update user profile&quot;</source>
         <translation>&quot;Обновление профиля пользователя&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="912"/>
+        <location filename="../src/servicemgr.cpp" line="931"/>
         <source>Account swiched to offline mode. Please check network settings and try again.</source>
         <translation>Учетная запись переключена в автономный режим. Пожалуйста, проверьте настройки соединения и попробуйте снова.</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="915"/>
+        <location filename="../src/servicemgr.cpp" line="934"/>
         <source>&quot;Get settings&quot;</source>
         <translation>&quot;Получение настроек&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="918"/>
+        <location filename="../src/servicemgr.cpp" line="937"/>
         <source>&quot;Set settings&quot;</source>
         <translation>&quot;Применение настроек&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="924"/>
+        <location filename="../src/servicemgr.cpp" line="943"/>
         <source>&quot;Download image&quot;</source>
         <translation>&quot;Получение изображения&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="927"/>
+        <location filename="../src/servicemgr.cpp" line="946"/>
         <source>&quot;Upload image&quot;</source>
         <translation>&quot;Загрузка изображения на сервис&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="929"/>
+        <location filename="../src/servicemgr.cpp" line="948"/>
         <source>&quot;Get comments&quot;</source>
         <translation>&quot;Получение комментариев&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="932"/>
+        <location filename="../src/servicemgr.cpp" line="951"/>
         <source>&quot;Send comment&quot;</source>
         <translation>&quot;Отправка комментария&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="935"/>
+        <location filename="../src/servicemgr.cpp" line="954"/>
+        <source>&quot;Get list of messages&quot;</source>
+        <translation>&quot;Получение сообщений&quot;</translation>
+    </message>
+    <message>
         <source>&quot;Get message inbox&quot;</source>
-        <translation>&quot;Получение списка входящих сообщений&quot;</translation>
+        <translation type="obsolete">&quot;Получение списка входящих сообщений&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="938"/>
         <source>&quot;Get message outbox&quot;</source>
-        <translation>&quot;Получение списка отправленных сообщений&quot;</translation>
+        <translation type="obsolete">&quot;Получение списка отправленных сообщений&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="941"/>
+        <location filename="../src/servicemgr.cpp" line="957"/>
         <source>&quot;Send message&quot;</source>
         <translation>&quot;Отправка сообщения&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="944"/>
+        <location filename="../src/servicemgr.cpp" line="960"/>
         <source>&quot;Mark message as read&quot;</source>
         <translation>&quot;Пометка сообщения прочитанным&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="947"/>
+        <location filename="../src/servicemgr.cpp" line="963"/>
         <source>&quot;Delete message&quot;</source>
         <translation>&quot;Удаление сообщения&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="950"/>
+        <location filename="../src/servicemgr.cpp" line="966"/>
         <source>&quot;Get list of registered methods&quot;</source>
         <translation>&quot;Получение списка поддерживаемых методов&quot;</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="953"/>
+        <location filename="../src/servicemgr.cpp" line="969"/>
         <source>&quot;Get feed&quot;</source>
         <translation>Получение новостей</translation>
     </message>
     <message>
-        <location filename="../src/servicemgr.cpp" line="960"/>
+        <location filename="../src/servicemgr.cpp" line="976"/>
         <source> from account &quot;%1&quot; the error %2 was caused: </source>
         <translation> от учетной записи &quot;%1&quot; получена ошибка %2: </translation>
     </message>
